--Levaks screen manager (a little lib to make life easy)

-----------------------------
-- Levak ©2011 --------------
-- http://levak.free.fr/ ----
-- levak92@gmail.com --------
-----------------------------

	ScoreList={}
	ScoreList[1] = {"Stefan", 42}
	ScoreList[2] = {"Jim", 13}

------ Screen Manager
Screen = {}
Screen.__index = function () return 0 end
setmetatable(Screen, Screen)

function Screen:paint(gc) end
function Screen:charIn(ch) end
function Screen:arrowUp() end
function Screen:arrowLeft() end
function Screen:arrowRight() end
function Screen:arrowDown() end
function Screen:escapeKey() end
function Screen:enterKey() end
function Screen:tabKey() end

Screens = {}

function PushScreen(screen)
	table.insert(Screens, screen)
	platform.window:invalidate()
end

function PullScreen()
	if #Screens > 1 then
		table.remove(Screens)
		platform.window:invalidate()
	end
end

function DrawSreens(gc)
	for _, screen in ipairs(Screens) do
		screen:paint(gc)
	end
end

function activeScreen()
	return Screens[#Screens]
end

-- Link events to ScreenManager

function on.paint(gc) DrawSreens(gc) end
function on.charIn(ch) activeScreen():charIn(ch) end
function on.arrowUp() activeScreen():arrowUp() end
function on.arrowLeft() activeScreen():arrowLeft() end
function on.arrowDown() activeScreen():arrowDown(key) end
function on.arrowRight() activeScreen():arrowRight(key) end
function on.escapeKey()	activeScreen():escapeKey() end
function on.enterKey() activeScreen():enterKey() end
function on.tabKey() activeScreen():tabKey() end
function on.timer() activeScreen():timer() end
function on.backspaceKey() activeScreen():backspaceKey() end

-----------------------------------------
--Start of the game code by Jim Bauwens--
-----------------------------------------

function nclass(t)
	t = class(t)
	t.mt = {__index=function (t) return t.mt.__index end}
	setmetatable(t,t.mt)
	return t
end


-----------
--Startup--
-----------

function on.create()
	SCREEN_W = platform.window:width()

	newGame(true)
	PushScreen(Menu)
	prepre=nil
end

--------
--Menu--
--------

Menu = nclass(Screen)

Menudex = 1
Menuto = 54
Menudir = 1
Menuy = 54

function drawStringMiddle(gc, tstring, y)
	local w = gc:getStringWidth(tstring)
	gc:drawString(tstring, (SCREEN_W/2)-(w/2), y, "top")
end

function Menupre(gc)
	FOUNDATIONS[1]={number=1, type=1}
	FOUNDATIONS[2]={number=2, type=2}
	FOUNDATIONS[3]={number=3, type=3}
	FOUNDATIONS[4]={number=4, type=4}
	Game:tabKey()
	gc:setColorRGB(255,255,255)
	gc:fillRect(0,0, 320, 240)
	drawTableau(gc)
	drawFoundation(gc)
	drawWaste(gc)
	
	prepre = true
end

function Menu:paint(gc)
	if not prepre then
		Menupre(gc)
	end
	
	gc:setColorRGB(4,250,4)
	gc:fillRect(35,35,SCREEN_W-70, 212-70)
	gc:setPen("medium","smooth")
	gc:setColorRGB(0,0,0)
	gc:drawRect(35,35,SCREEN_W-70, 212-70)
	
	gc:setColorRGB(4,170,4)
	gc:fillRect((SCREEN_W/2)-75, Menuy,150,25)

	gc:setColorRGB(0,0,0)
	gc:drawRect((SCREEN_W/2)-75, Menuy,150,25)
	
	gc:setFont("serif","b",11)
	
	drawStringMiddle(gc,"New Game", 55)
	if not oldgame then gc:setColorRGB(100,100,100) end
	
	drawStringMiddle(gc,"Load saved game", 80)
	gc:setColorRGB(0,0,0)
	drawStringMiddle(gc,"High Scores", 105)
	drawStringMiddle(gc,"About", 130)
end

function Menu:arrowUp()
	if Menudex~=1 then
		Menudex = Menudex - 1
		Menuto = Menuto - 25
		Menudir = -2.5
		timer.start(0.01)
	end
end

function Menu:arrowDown()
	if Menudex<4 then
		Menudex = Menudex + 1
		Menuto = Menuto + 25
		Menudir = 2.5
		timer.start(0.01)
	end
end

function Menu:timer()
	if Menuto == Menuy then
		timer.stop()
	else
		Menuy = Menuy + Menudir
		platform.window:invalidate(35,35,SCREEN_W-70, 212-70)
	end
end

function Menu:enterKey()
	if Menudex == 1 then
		newGame()
		Screens = {Game, NamePrompt}
		platform.window:invalidate()
	elseif Menudex == 2  and oldgame then
		oldGame()
	elseif Menudex == 3 then
		Screens = {Scores}
		platform.window:invalidate()
	elseif Menudex == 4 then 
		Screens = {ABOUT}
		platform.window:invalidate()
	end
end

---------------
--High Scores--
---------------

Scores = nclass(Screen)

function Scores:paint(gc)
	gc:setColorRGB(4,250,4)
	gc:fillRect(35,35,SCREEN_W-70, 212-70)
	gc:setPen("medium","smooth")
	gc:setColorRGB(0,0,0)
	gc:drawRect(35,35,SCREEN_W-70, 212-70)
	
	gc:setColorRGB(100,100,100)
	gc:setPen("thin","smooth")
	gc:fillRect(55,37,1,209-70)
	gc:fillRect(185,37,1,209-70)
	
	gc:setColorRGB(0,0,0)
	gc:setFont("serif","b",11)
	
	gc:drawString("N°", 38, 55)
	gc:drawString("Name",57,55)
	gc:drawString("Score",187,55)
	
	for i=1, 8 do
		gc:drawString(tostring(i), 42, i*14 + 59)
		gc:fillRect(36,i*14 + 44, SCREEN_W-70,1)
	end
	
	
	gc:setFont("serif","r",10)
	for ScoreItem=1, math.min(#ScoreList, 8) do
		gc:drawString(ScoreList[ScoreItem][1], 57, ScoreItem*14 + 58)
		gc:drawString(tostring(ScoreList[ScoreItem][2]), 187, ScoreItem*14 + 58)
	end
end

function Scores:enterKey()
	Screens = {Menu}
	prepre = nil
	platform.window:invalidate()
end

function Scores:escapeKey()
	Screens = {Menu}
	prepre = nil
	platform.window:invalidate()
end

function addScore(name, score)
	for ScoreItem=1, #ScoreList do
		if ScoreList[ScoreItem][2]<score then
			table.insert(ScoreList, ScoreItem, {name, score})
			return ScoreItem
		end
	end
	table.insert(ScoreList, {name, score})
	return #ScoreList
end

-----------------------
--Request name prompt--
-----------------------

NamePrompt = nclass(Screen)
NameName = ""

function NamePrompt:paint(gc)
	gc:setColorRGB(4,250,4)
	gc:fillRect(35,212/2-20,SCREEN_W-70, 40)
	gc:setPen("medium","smooth")
	gc:setColorRGB(0,0,0)
	gc:drawRect(35,212/2-20,SCREEN_W-70, 40)
	
	drawStringMiddle(gc, "Enter your name", 212/2-18)
	gc:setPen("thin","smooth")
	gc:drawRect(40,212/2-4,SCREEN_W-80, 20)
	gc:drawString(NameName,42,212/2-1, "top")
end

function NamePrompt:charIn(ch)
	if #NameName>20 then return end
	NameName = NameName .. ch
	platform.window:invalidate()
end

function NamePrompt:enterKey()
	PullScreen()
	platform.window:invalidate()
end

function NamePrompt:backspaceKey()
	NameName = NameName:sub(1, #NameName-1)
	platform.window:invalidate()
end
--------------------------
--Create the game screen--
--------------------------

Game = nclass(Screen)

-----------------
--Load old game--
-----------------

function oldGame()
	TABLEAU = oldgame.TABLEAU
	SCORE = oldgame.SCORE
	FOUNDATIONS = oldgame.FOUNDATIONS
	WASTE = oldgame.WASTE
	Selection = oldgame.Selection
	MOVING = oldgame.MOVING
	NameName = oldgame.NameName
	Screens = {Game}
	platform.window:invalidate()
end
--------------------
--Start a new game--
--------------------

function newGame(x)

	TABLEAU = {}
	TABLEAU[1] = {}
	TABLEAU[2] = {}
	TABLEAU[3] = {}
	TABLEAU[4] = {}
	TABLEAU[5] = {}
	TABLEAU[6] = {}
	TABLEAU[7] = {}

	FOUNDATIONS = {}
	FOUNDATIONS[1] = {number=0}
	FOUNDATIONS[2] = {number=0}
	FOUNDATIONS[3] = {number=0}
	FOUNDATIONS[4] = {number=0}

	WASTE = {}
	WASTE.turned = {}
	WASTE.unturned = {}

	MOVING = {}
	MOVING.ismoveing = false
	MOVING.fromstack = 0
	MOVING.movestack = {}

	SCORE = 0

	Selection = {stack=1, selected=1}
	
	fillcards(randdeck(x))
end

---------------------
--Randomize a table--
---------------------

function randt(a)
	local b={}
	while #a>0 do
		table.insert(b, table.remove(a, math.random(#a)))
	end
	return b
end

---------------------------------
--Create a sorted deck of cards--
---------------------------------

function gendeck(x)
	local col = 0
	local carddeck = {}
	
	for c=1, 4 do
		if c>2 then col=2 else col=1 end
		for n=1, 13 do
			table.insert(carddeck, {number=n, type=c, color=col, visible=x})
		end
	end
	return carddeck
end

---------------------------------
--Create a random deck of cards--
---------------------------------

function randdeck(x)
	return randt(gendeck(x))
end

--Fill the TABLEAU and Waste with deck
function fillcards(deck)
	for card=1, 24 do
		table.insert(WASTE.unturned, table.remove(deck))
	end
	
	for tabl=1, 7 do
		for i=1, tabl do
			table.insert(TABLEAU[tabl], table.remove(deck))
		end
		TABLEAU[tabl][tabl].visible = true
	end
	
	--[[
	TABLEAU[1]={{type=1,color=1, number=13, visible=true}}
	TABLEAU[2]={{type=2,color=1, number=13, visible=true}}
	TABLEAU[3]={{type=3,color=2, number=13, visible=true}}
	TABLEAU[4]={{type=4,color=2, number=13, visible=true}}
	
	FOUNDATIONS[1] = {type=1, number=12}
	FOUNDATIONS[2] = {type=2, number=12}
	FOUNDATIONS[3] = {type=3, number=12}
	FOUNDATIONS[4] = {type=4, number=12}
	--]]
end

------------------------
--Draw a deck of cards--
------------------------

function drawdeck(gc, stck, x, y)
	local amount = #stck
	local ccard = {}
	local pos = 0
	
	if amount == 0 then
		gc:setColorRGB(170, 170, 170)
		gc:drawRect(x, y, 39, 51)
		return 0 
	end
	
	for card=1, amount do
		ccard = stck[card]
		
		if card~=amount then
			if ccard.visible then
				gc:setColorRGB(255,255,255)
				gc:fillRect(x+1, y+pos, 37, 11)
				gc:drawImage(cards[ccard.type][ccard.number].top, x, y+pos)
				pos = pos + 11
			else
				gc:setColorRGB(255,255,255)
				gc:fillRect(x+1, y+pos+1, 37, 3)
				gc:drawImage(cardback.top, x, y+pos)
				pos = pos + 4			
			end
		else
			if ccard.visible then
				gc:setColorRGB(255,255,255)
				gc:fillRect(x+1, y+pos+1, 37, 49)
				
				gc:drawImage(cards[ccard.type][ccard.number].top, x, y+pos)
				gc:drawImage(cards[ccard.type][ccard.number].bottom, x, y+pos+11)
			else
				gc:setColorRGB(255,255,255)
				gc:fillRect(x, y+pos, 39, 51)
				gc:drawImage(cardback.top, x, y+pos)
				gc:drawImage(cardback.bottom, x, y+pos+11)			
			end
			pos = pos + 51
		end		
	end

	gc:setColorRGB(0,0,0)
	gc:fillRect(x, y+2, 1, pos-4)
	gc:fillRect(x+38, y+2, 1, pos-4)
	
	return pos
end

----------------------
--Draw the Tableau's--
----------------------

function drawTableau(gc)
	for tabl=1, 7 do
		TABLEAU[tabl].pos = drawdeck(gc, TABLEAU[tabl],4 + (tabl - 1) * (39 + 6), 60)
	end
end

-----------------------
--Draw the waste pile--
-----------------------

function drawWaste(gc)
	if #WASTE.unturned~=0 then
		gc:setColorRGB(255,255,255)
		gc:fillRect(5,3,37,49)
		gc:drawImage(cardback.top, 4, 2)
		gc:drawImage(cardback.bottom, 4, 13)
	end
	
	local ws = WASTE.turned
	local tw = #ws
	
	if tw>2 then
		gc:setColorRGB(255,255,255)
		gc:fillRect(50, 3, 37, 49)
		gc:drawImage(cards[ws[tw-2].type][ws[tw-2].number].top, 29 + 1*20, 2)
		gc:drawImage(cards[ws[tw-2].type][ws[tw-2].number].bottom, 29 + 1*20, 13)
	end
	if tw>1 then
		gc:setColorRGB(255,255,255)
		gc:fillRect(70, 3, 37, 49)
		gc:drawImage(cards[ws[tw-1].type][ws[tw-1].number].top, 29 + 2*20, 2)
		gc:drawImage(cards[ws[tw-1].type][ws[tw-1].number].bottom, 29 + 2*20, 13)
	end
	if tw>0 then
		gc:setColorRGB(255,255,255)
		gc:fillRect(90, 3, 37, 49)
		gc:drawImage(cards[ws[tw].type][ws[tw].number].top, 29 + 3*20, 2)
		gc:drawImage(cards[ws[tw].type][ws[tw].number].bottom, 29 + 3*20, 13)
	end
end

--------------------
--Draw Foundations--
--------------------

function drawFoundation(gc)
	for found=1, 4 do
		if FOUNDATIONS[found].number ~= 0 then
			gc:setColorRGB(255,255,255)
			gc:fillRect(112 + found*41, 3, 37, 49)
			gc:drawImage(cards[FOUNDATIONS[found].type][FOUNDATIONS[found].number].top,111 + found*41, 2)
			gc:drawImage(cards[FOUNDATIONS[found].type][FOUNDATIONS[found].number].bottom,111 + found*41, 2+11)
		else
			gc:setColorRGB(120, 120, 120)
			gc:drawRect(111 + found*41, 2, 39, 51)
		end
	end
end

----------------------
--Draw the selection--
----------------------

function drawSelection(gc)
	local selection = Selection.stack
	local selected = Selection.selected
	
	if selection == 0 then
		gc:setColorRGB(0,0,0)
		gc:setPen("medium","smooth")
		gc:drawRect(89, 2, 39, 51)	
	elseif selection<8 then
		local stackpos = TABLEAU[selection].pos
		if stackpos == 0 then stackpos = 51 end
		local height = 52 + (selected-1) * 11
		gc:setColorRGB(0,0,0)
		gc:setPen("medium","smooth")
		gc:drawRect(3 + (selection - 1) * (39 + 6), 60 + stackpos-height, 40, height)
	else
		gc:setColorRGB(0,0,0)
		gc:setPen("medium","smooth")
		gc:drawRect(111 + (selection-7)*41, 2, 39, 51)
	end
end

---------------------
--Shuffle the waste--
---------------------

function shuffleWaste()
	if #WASTE.unturned>0 then
		for i=1, math.min(3, #WASTE.unturned) do
			table.insert(WASTE.turned, table.remove(WASTE.unturned))
		end
	else
		for i=1, #WASTE.turned do
			table.insert(WASTE.unturned, table.remove(WASTE.turned))
		end
	end
end


--------------------------------------
--Draw the stack that is being moved--
--------------------------------------

function drawMove(gc)
	local selection = Selection.stack
	
	if selection == 0 then
		drawdeck(gc, MOVING.movestack, 86, 22, 39, 51)
	elseif selection<8 then 
		local stackpos = TABLEAU[selection].pos	
		if stackpos == 0 then stackpos = 51 end
		drawdeck(gc, MOVING.movestack, (selection - 1) * (45), 20 + stackpos)
	else
		drawdeck(gc, MOVING.movestack, 108 + (selection-7)*41, 12, 39, 51)
	end
end

---------------------------
--Take card of waste pile--
---------------------------

function Game:backspaceKey()
	if #WASTE.turned>0 and not MOVING.ismoving then
		MOVING.fromstack = 0
		MOVING.movestack = {}		
		
		local ccard = table.remove(WASTE.turned)

		MOVING.movestack[1] = {}
		MOVING.movestack[1].number	= ccard.number
		MOVING.movestack[1].type	= ccard.type
		MOVING.movestack[1].color	= ccard.color
		MOVING.movestack[1].visible	= true

		MOVING.ismoving = true

	end
	platform.window:invalidate()
end

--------------------------
--Shuffle the waste pile--
--------------------------

function Game:tabKey()
	if not MOVING.ismoving then
		shuffleWaste()
		Selection.stack = 0
	end
	platform.window:invalidate()
end

---------------------------------------------------------
--Main function, place/take cards, calculate everything--
---------------------------------------------------------

function Game:enterKey()	
	-------------------------------------
	--If (a) card(s) is/are being moved--
	-------------------------------------
	
	if MOVING.ismoving then
		-------------------------------------------------------------------------------
		-- If the card is taken from the wastepile, and the user wants to put it back--
		-------------------------------------------------------------------------------
		
		if Selection.stack == 0 then
			if MOVING.fromstack == 0 then
				table.insert(WASTE.turned, table.remove(MOVING.movestack))
				
				MOVING.ismoving = false	
			end
		
		-----------------------------
		--If placing on the Tableau--
		-----------------------------
		
		elseif Selection.stack<8 then
		
			--If the card is invalid
			local selStack = TABLEAU[Selection.stack]
			if (#selStack>0 and (selStack[#selStack].color == MOVING.movestack[1].color or selStack[#selStack].number ~= MOVING.movestack[1].number + 1)) or (#selStack == 0 and MOVING.movestack[1].number ~= 13) then
				Selection.stack = MOVING.fromstack
			end 
			
			
			if Selection.stack>0 and Selection.stack<8 then
				--Move the cards		
							
				for i=1, #MOVING.movestack do
					tmp = table.remove(MOVING.movestack, 1)
					if tmp then	table.insert(TABLEAU[Selection.stack], tmp) end
				end	
				
				if MOVING.fromstack == 0 then
					SCORE = SCORE + 5
				elseif MOVING.fromstack>7 then
					SCORE = SCORE - 15
				end
			
				--Unhide card if needed
				if MOVING.fromstack>0 and MOVING.fromstack<8 and Selection.stack ~= MOVING.fromstack  and #TABLEAU[MOVING.fromstack]>0 then
					if not TABLEAU[MOVING.fromstack][#TABLEAU[MOVING.fromstack]].visible then
						TABLEAU[MOVING.fromstack][#TABLEAU[MOVING.fromstack]].visible = true
						SCORE = SCORE + 5
					end
				end
			else
				Game:enterKey()
			end
			
			MOVING.ismoving = false	
			--Selection.stack = MOVING.fromstack
			
		--------------------------------	
		--If placing on the foundation--
		--------------------------------
		else 		
			--If the card is invalid
			if (#MOVING.movestack>1 or MOVING.movestack[1].number ~= FOUNDATIONS[Selection.stack-7].number + 1 or (FOUNDATIONS[Selection.stack-7].type and FOUNDATIONS[Selection.stack-7].type ~= MOVING.movestack[1].type)) then
				if MOVING.fromstack<8 then
					Selection.stack = MOVING.fromstack
					Game:enterKey()
				else
					FOUNDATIONS[MOVING.fromstack-7] = table.remove(MOVING.movestack, 1)
				end
					
			--If the card is valid	
			else
				--move the card
				FOUNDATIONS[Selection.stack-7] = table.remove(MOVING.movestack, 1)
				
				if MOVING.fromstack<8 then
					SCORE = SCORE + 10
				end
				
				if FOUNDATIONS[1].number == 13 and FOUNDATIONS[2].number == 13 and FOUNDATIONS[3].number == 13 and FOUNDATIONS[4].number == 13 then
					win()
				end
				
				--Unhide a card if needed
				if MOVING.fromstack>0 and MOVING.fromstack<8 and #TABLEAU[MOVING.fromstack]>0 then
					if not TABLEAU[MOVING.fromstack][#TABLEAU[MOVING.fromstack]].visible then
						TABLEAU[MOVING.fromstack][#TABLEAU[MOVING.fromstack]].visible = true
						SCORE = SCORE + 5
					end
				end
			end 
			
			MOVING.ismoving = false	
			--Selection.stack = MOVING.fromstack		
		end
	
	--------------------------------
	--If the user is taking a card--
	--------------------------------
	
	else 
		local tmp = {}
		MOVING.fromstack = Selection.stack
		MOVING.movestack = {}	
		
		if Selection.stack == 0 then
			Game:backspaceKey()
			
		elseif Selection.stack<8 then
			if #TABLEAU[Selection.stack]>0 then
				for i=1, Selection.selected do
					tmp = table.remove(TABLEAU[Selection.stack])
					if tmp then MOVING.movestack[Selection.selected-i+1] = tmp end
				end
				MOVING.ismoving = true
			end
			
		elseif FOUNDATIONS[MOVING.fromstack-7].number>0 then
			MOVING.movestack[1] = {}
			MOVING.movestack[1].number = FOUNDATIONS[MOVING.fromstack-7].number
			MOVING.movestack[1].type = FOUNDATIONS[MOVING.fromstack-7].type
			MOVING.movestack[1].color = FOUNDATIONS[MOVING.fromstack-7].color
			MOVING.movestack[1].visible = FOUNDATIONS[MOVING.fromstack-7].visible
			FOUNDATIONS[MOVING.fromstack-7].number = FOUNDATIONS[MOVING.fromstack-7].number-1
			if FOUNDATIONS[MOVING.fromstack-7].number == 0 then FOUNDATIONS[MOVING.fromstack-7].type = nil end
			MOVING.ismoving = true
		end
		
		Selection.selected = 1
	end
	
	
	platform.window:invalidate()
end

--------------------------------
--If user presses the up arrow--
--------------------------------

function Game:arrowUp()
	if Selection.stack==0 or Selection.stack>7 then return end
	
	local lenStack = #TABLEAU[Selection.stack]
	if Selection.selected<lenStack and TABLEAU[Selection.stack][lenStack-Selection.selected].visible and not MOVING.ismoving then
		Selection.selected = Selection.selected+1
	elseif Selection.stack>3 and Selection.stack<8 then
		Selection.selected = 1
		Selection.stack = Selection.stack + 4
	elseif Selection.stack<4 then
		Selection.selected = 1
		Selection.stack = 0
	end
	platform.window:invalidate()
end

----------------------------------
--If user presses the down arrow--
----------------------------------

function Game:arrowDown()
	if Selection.selected>1 then
		Selection.selected = Selection.selected-1
	elseif Selection.stack == 0 then
		Selection.stack = 3
	elseif Selection.stack>7 then
		Selection.stack = Selection.stack - 4
	end
	platform.window:invalidate()
end

----------------------------------
--If user presses the left arrow--
----------------------------------

function Game:arrowLeft()
	if Selection.stack>0 and Selection.stack ~= 8 then
		Selection.stack = Selection.stack - 1
		Selection.selected = 1
	elseif Selection.stack == 8 then
		Selection.stack = 0
	end
	platform.window:invalidate()
end

-----------------------------------
--If user presses the right arrow--
-----------------------------------

function Game:arrowRight()
	if Selection.stack<11 and Selection.stack ~= 0 then
		Selection.stack = Selection.stack + 1
		Selection.selected = 1
	elseif Selection.stack == 0 then
		Selection.stack = 8
	end
	platform.window:invalidate()
end

----------------------------------
--Paint everything on the screen--
----------------------------------

function Game:paint(gc)
	gc:setColorRGB(4,250,4)
	gc:fillRect(0,0, 320, 240)
	drawTableau(gc)
	drawFoundation(gc)
	drawWaste(gc)
	
	if MOVING.ismoving then
		drawMove(gc)
	else
		drawSelection(gc)
	end
	
	gc:setFont("serif", "b", 8)
	gc:drawString("Score: " .. tostring(SCORE), 1,200,"top")
	
end

function Game:escapeKey()
	Screens = {InGameMenu}
	platform.window:invalidate(34,34,SCREEN_W-69, 212-69)
end

InGameMenu = nclass(Screen)
InGameMenudex = 1
InGameMenuto = 54
InGameMenudir = 1
InGameMenuy = 54

function InGameMenu:paint(gc)
	gc:setColorRGB(4,250,4)
	gc:fillRect(35,35,SCREEN_W-70, 212-70)
	gc:setPen("medium","smooth")
	gc:setColorRGB(0,0,0)
	gc:drawRect(35,35,SCREEN_W-72, 212-72)
	
	gc:setColorRGB(4,170,4)
	gc:fillRect((SCREEN_W/2)-75, InGameMenuy,150,25)

	gc:setColorRGB(0,0,0)
	gc:drawRect((SCREEN_W/2)-75, InGameMenuy,150,25)
	
	gc:setFont("serif","b",11)
	
	drawStringMiddle(gc,"Continue", 55)
	drawStringMiddle(gc,"Save Game", 80)
	drawStringMiddle(gc,"New Game", 105)
	drawStringMiddle(gc,"Stop Game", 130)
end

function InGameMenu:arrowUp()
	if InGameMenudex~=1 then
		InGameMenudex = InGameMenudex - 1
		InGameMenuto = InGameMenuto - 25
		InGameMenudir = -2.5
		timer.start(0.01)
	end
end

function InGameMenu:arrowDown()
	if InGameMenudex<4 then
		InGameMenudex = InGameMenudex + 1
		InGameMenuto = InGameMenuto + 25
		InGameMenudir = 2.5
		timer.start(0.01)
	end
end

function InGameMenu:timer()
	if InGameMenuto == InGameMenuy then
		timer.stop()
	else
		InGameMenuy = InGameMenuy + InGameMenudir
		platform.window:invalidate(34,34,SCREEN_W-69, 212-69)
	end
end

function InGameMenu:enterKey()
	if InGameMenudex == 1 then
		Screens={Game}
		platform.window:invalidate()
	elseif InGameMenudex == 3 then
		newGame()
		Screens = {Game}
		platform.window:invalidate()		
	elseif InGameMenudex == 2 then
		oldgame = {}
		oldgame.TABLEAU = TABLEAU
		oldgame.SCORE = SCORE
		oldgame.FOUNDATIONS = {}
		oldgame.FOUNDATIONS[1] = {type=FOUNDATIONS[1].type, number=FOUNDATIONS[1].number, color=FOUNDATIONS[1].color, visible=FOUNDATIONS[1].visible}
		oldgame.FOUNDATIONS[2] = {type=FOUNDATIONS[2].type, number=FOUNDATIONS[2].number, color=FOUNDATIONS[2].color, visible=FOUNDATIONS[2].visible}
		oldgame.FOUNDATIONS[3] = {type=FOUNDATIONS[3].type, number=FOUNDATIONS[3].number, color=FOUNDATIONS[3].color, visible=FOUNDATIONS[3].visible}
		oldgame.FOUNDATIONS[4] = {type=FOUNDATIONS[4].type, number=FOUNDATIONS[4].number, color=FOUNDATIONS[4].color, visible=FOUNDATIONS[4].visible}
		oldgame.WASTE = {}
		oldgame.WASTE.turned = WASTE.turned
		oldgame.WASTE.unturned = WASTE.unturned
		oldgame.Selection = Selection
		oldgame.MOVING = MOVING
		oldgame.NameName = NameName
		document.markChanged()
		Screens = {Game}
		platform.window:invalidate()			
	else 
		Screens={Menu}
		prepre=nil
		platform.window:invalidate()
	end
	
	InGameMenudex = 1
	InGameMenuto = 54
	InGameMenudir = 1
	InGameMenuy = 54
end

function InGameMenu:escapeKey()
	InGameMenudex = 1
	InGameMenuto = 54
	InGameMenudir = 1
	InGameMenuy = 54
	Screens={Game}
	platform.window:invalidate()	
end

----------------
--About screen--
----------------

ABOUT = nclass(Screen)

function ABOUT:paint(gc)
	gc:setColorRGB(4,250,4)
	gc:fillRect(35,35,SCREEN_W-70, 212-70)
	gc:setPen("medium","smooth")
	gc:setColorRGB(0,0,0)
	gc:drawRect(35,35,SCREEN_W-72, 212-72)
	
	gc:setFont("serif","b",11)
	
	drawStringMiddle(gc,"Klondike Lua (1.0)", 50)
	drawStringMiddle(gc,"By", 70)
	drawStringMiddle(gc,"Jim Bauwens", 90)
	drawStringMiddle(gc,"Thanks to", 120)
	gc:setFont("serif","r",10)
	drawStringMiddle(gc, "Omnimaga, Ti-Bank, Adriweb and Levak", 140)
end

function ABOUT:enterKey()
	prepre = nil
	Screens = {Menu}
	platform.window:invalidate()
end

function ABOUT:escapeKey()
	prepre = nil
	Screens = {Menu}
	platform.window:invalidate()
end
--------------------
--WIN WIN WIN WIN!--
--------------------

function win()
	Level = addScore(NameName, SCORE)
	document.markChanged()
	toadd = nil
	if Level<11 then
		toadd = true
	end
	
	Screens = {WIN}
	platform.window:invalidate()
end

WIN = nclass(Screen)

function WIN:paint(gc)
	gc:setColorRGB(4,250,2)
	gc:fillRect(SCREEN_W/2-155, 212/2-20, 310, 40)
	gc:setColorRGB(0,0,0)
	gc:setPen("medium","smooth")
	gc:drawRect(SCREEN_W/2-155, 212/2-20, 310, 40)
	
	gc:setFont("serif","b",12)
	drawStringMiddle(gc, "Congratulations, you have solved this game!", 212/2-20)
	if toadd then
		drawStringMiddle(gc, "And you are in the top 10!",212/2)
	else
		gc:setFont("serif","r",12)
		drawStringMiddle(gc, "Your posistion in the ladder is #" .. tostring(SCORE),212/2)
	end
end

function WIN:enterKey(gc)
	prepre=nil
	Screens = {Menu}
	platform.window:invalidate()
	
end

function on.save()
	return {ScoreList, oldgame}
end

function on.restore(data)
	ScoreList=data[1]
	oldgame=data[2]
end
---------------------------------------------------------------------------------
------------------------------SPRITE DATA----------------------------------------
--------------- Some text editors might crash if you scroll below! --------------
---------------------------------------------------------------------------------












cardback = {}

cardback.top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000al\223\251!\132\000\128\000\128\000\128\034\132\001\128\000\128 \128\000\128\000\128\000\128\000\128\000\128\000\128 \132\000\128@\132 \128\000\128\001\128\001\128\000\128\000\128\000\128\000\128\000\128\000\128 \132\000\128\001\128\000\128\000\128\000\128!\132\001\128alalal\001\128al\254\255\253\255\188\247alal\255\251alalal\254\255\254al\255al\221\251\254\255\253\255alalalalalal\254al\255\254\255\221\251\254alalal\255alalalal\001\128al\000\128al\254\255\254\255\253\255\254al\255alal\254al\255al\253\251\254\255\190\247alal\223alalal\255\254\255\254\255\253\251\253\255\254alalalalalalalal\255al\190\251\223al\255\001\128\001\128al\254\255\000\128 \132\000\128\002\128\003\128\004\128\005\132\003\128\003\128\001\128\001\128\034\132\002\128\003\128\004\128\004\128\004\128\004\128\003\128\000\128 \128 \132\000\128$\132\004\128\004\128\004\128\005\128\003\128\001\128\000\128B\136!\132\223\251al\000\128\000\128al\255\251!\132\223\251\002\128\244\189\149\181\154\185\155\185\154\185\216\189\212\189\003\128al\003\128\182\189w\181\187\189{\185{\185\185\189\210\185\000\128\254\255\002\128t\181\219\193\154\185\154\185\220\193\183\185\210\189\000\128al\000\128alal\000\128\000\128\221\247al\034\132al\223\255\004\128\216\189\189\189]\181\188\189\184\185\006\128\223\251alal\007\128\185\189|\185\158\189\157\189\186\189\004\128al\254al\255\008\132y\181\156\185\157\185{\185\151\185\003\128alal\000\128alal\000\128 \128\254al\255\000\128alal\223\251\005\128\186\189y\181\183\185\006\128alalalal\223\255\006\132\152\185\153\185\183\189\005\128alalalal\223\251\006\128\218\193x\181\214\189\004\128al\223\251\223\251!\132alal \132\000\128\254al\255\000\128alalalal\008\128\183\189\006\132\223\251alalalal\254\255\223\255\007\128\215\189\004\128alalal\254\255\221\251al\223\255\008\128\182\189\003\128al\223\251alal\000\128al\254\255\000\128\002\128alal\001\128\223\251alalal\223\255\005\128alalalalalal\253\255al\223\255\005\128\223\255\223\251al\254\255\253\251\254al\255\223\251\223\255\004\128al\223\251\223\251al\223\255\000\128al\254\255\000\128\002\128\223\251al\001\128alalal\223\255\006\128\213\189\003\128alalalalalalal\006\132\181\185\006\128\223al\255\254\255\253\255\220\247al\223\255\006\128\213\189\004\128alal\191\247al\000\128alal\000\128\000\128\254al\255\002\128al\223\251al\006\128\153\185\187\189\183\185\005\128al\254al\255\223\251\223\255\006\128\185\185\155\185\186\189\009\132\223\255\223\251alal\223\255\007\128w\181\154\185\152\181\009\132\191\251alal!\132al\254\255 \132")

cardback.bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000 \128\252al\255\002\128\223\251al\006\128\151\185\156\185}\185\154\185\183\185\004\128\223\251al\223\255\007\128\152\185\156\185\157\185|\185\154\185\007\128\223alal\255\006\128\185\185\188\189\157\189\156\185\153\181\006\128al\223\251\001\128al\254\255\000\128 \128\252\255\253\255\000\128al\006\128\152\185\188\189\157\189\156\185{\181\187\189\150\181\007\132\223\255\006\128\186\189{\185\190\193|\185\158\185\189\189\151\185\006\128\191\251\007\128\153\185\156\189\156\189\157\185~\185\156\189\181\185\004\132al\001\128al\254\255\000\128\000\128\220\247\253\255\000\128\002\128\213\189\154\185\156\185\157\189|\181\190\193\155\185\153\185\183\189\005\128\214\189x\181\189\189\157\185\157\185\159\185\156\185\249\193\213\189\006\128\149\185\186\189\189\189[\181\157\189\159\189\155\185t\181\244\193\003\128\001\128al\254\255\000\128\034\132\223\251al\001\128\223\251\005\128\184\189\155\185|\181\191\193~\185\156\185\183\185\005\128al\004\128\215\189\154\185|\181\191\193~\181\155\185\214\189\004\128\223\251\005\132\150\181z\181\223\193]\181\158\189\188\189\215\193\004\128al\002\128\223\255alA\136\002\128al\191\247\001\128alal\006\128\185\189\156\189|\185\157\189\153\185\007\128al\223\251al\005\128\184\189\156\189}\181\189\189\185\189\005\128alalal\005\128\184\189\155\185\157\185\155\185\185\185\006\128\223al\255\001\128alal\000\128\002\128alal\001\128\253\251\254\255\223\251\006\132\151\185\187\189\184\185\007\128alalal\255\251al\005\128\152\185\154\185\183\185\005\128al\254\255\253\255\253\255\223\251\005\128\185\189\186\189\150\185\005\128al\223al\255 \132\221\251\254\255\000\128\034\132\223\251al\000\128\254\255\253\255\254\255\191\247\007\128\150\181\007\132\223\251al\221\251alalalal\008\132\182\185\006\132\191\251al\253\255\253\255\220\251alal\007\128\182\185\004\128al\223\251al\254\255\000\128\254\255\221\251\000\128\001\128al\189\247 \128\255\251alalal\223\255\005\128\223\251alal\223\251alalalal\223\255\004\128\223\251alalal\222\247alal\223\251\223\255\004\128al\255\251alalal\000\128al\254\255\000\128 \128al\254\255\000\128alal\223\251\223\255\006\128\180\185$\132\223\251\223\251alalalalal\005\128\179\185\005\132\223\255\223\251alal\223\251\223\255\223\255\004\128\244\193\003\128al\223\251alal\000\128alal \132\000\128\254\255\254\255\000\128al\223\251\223\255\007\132\152\185\218\189\150\181\006\128alalalal\223\251\007\128\185\189\186\189\183\185\009\132\223\255\223alalal\255\006\128\217\193x\181\184\185\007\128\223alal\255\001\128alal\000\128\000\128\254\255\254\255\000\128al\223\251\007\128\151\181z\181\156\189\155\189\151\185\005\128\223alal\255\007\128\218\193Y\177\157\189\155\185W\177\007\132\223\255\223\251al\006\128\184\189\154\185\156\185\156\189\185\185\005\128al\223\251\002\132alal\000\128 \132\254al\255\000\128\223\251\005\128\152\185\189\189\157\189\157\185}\181\188\189\151\185\007\132\223\255\005\128\184\185y\181\222\193\158\189\159\185\156\185\216\193\006\128\223\255\007\128\153\185\157\189\156\185\157\189\156\185\154\185\181\189\003\128\223\255\002\128alalA\132\000\128al\223\251\000\128#\132\179\185\154\185\157\185\157\189|\185\159\189}\185\185\185\181\185\005\128\214\189\185\185\189\189|\185\158\189^\181\157\189\183\189\179\185\005\128\181\185\188\189\092\181\190\189}\185|\181\187\189\181\185\210\185\003\128\002\128alal\000\128\001\128al\255\251!\132al\004\128\186\189{\185\155\185\188\189\157\189{\181\184\189\006\128\223\255\006\128\153\185{\185\190\189\157\185\157\185\187\189\180\185\003\128al\005\128\184\185\188\189\157\185}\185\158\185\155\185\213\189\003\128al\002\128alal \128\034\132alal\001\128al\223\251\008\128\186\189\186\189x\181\154\185\185\189\007\128\223\255\223\251\223\255\009\136\153\185{\185\156\185\154\185\151\185\005\128al\223\251al\007\128w\181\221\193{\181\189\189\153\185\006\132\223\255\223\255\002\128alal\000\128\000\128\190\247al\000\128alalal\007\128\183\185\217\193\182\185\006\128alal\254al\255\223\251\006\128\186\189\154\185\216\189\006\128\223\255\223\251alalal\004\128w\181\187\189\151\185\006\128\223alal\255\001\128alal \128\000\128alal\000\128alal\190\247al\006\128\149\185\005\128alal\254\255\253\255\254alal\255\008\128\184\189\005\128\223\251alalalal\254\255\223\251\008\132\216\189\006\128\223alal\255\191\251!\132alal \132\001\128alal \128alalalal\223\255\004\128\223\255alalalalalalal\223\255\005\128alal\190\247alalal\254al\255\223\255\005\128\223al\255\223\251alal\000\128alal\000\128\000\128al\254\255\000\128al\223\251al\223\251\005\128\180\185\004\132al\223\251alalalalal\005\128\212\189\003\128alalalalalal\223\251\006\128\212\185\004\128\223\251alalal\000\128alal\000\128\000\128\254al\255\000\128alalal\005\128\186\189x\181\217\189\007\128\223\251alalalal\006\128\185\189\153\185\216\189\006\128alalalal\223\251\008\132\184\189\184\185\183\185\006\128alal\254\255\000\128\221\251\254\255 \132 \128\254\255al\000\128alal\005\128\216\189\156\185\190\189{\185\152\185\006\132\223\251alal\006\128\151\185\156\189\157\185{\185\218\193\006\128alal\223\255\007\128\184\185\155\185\155\185\187\189\184\189\005\128\223al\255\000\128\254\255\221\251\000\128\000\128\254\255\221\251\000\128al\006\128\151\181\188\189\158\185]\181~\185\189\193\151\181\007\128\223\255\005\128\151\185\155\189\159\189\127\185\158\189\155\185\151\181\008\132\223\255\006\128\185\189Z\181\158\185\191\193|\181\156\189\184\185\006\128\223\255\001\128\254\255\254\255\000\128\000\128\222\255\254\255\000\128\002\128\213\189\153\181}\185}\181\223\193~\185\156\185\185\189\182\189\004\128\180\185\185\189\156\189~\185^\181\158\189\156\185\217\189\149\185\006\128\181\185\187\189\157\189\158\185\092\181\191\189\156\185\185\189\182\189\004\128\034\132\254\255\253\255\000\128!\136\254\255\221\251\000\128al\005\128\185\189\156\185\158\189\092\177\157\185\155\185\216\193\004\128al\003\128\152\185\155\185\188\189\189\189{\181\186\189\181\185\004\128\223\255\006\128\185\189z\181\155\185\189\189|\181\155\185\215\189\004\128al\002\132al\254\255!\132\000\128alal!\132al\223\255\006\128\185\185{\181\189\189\187\189\150\181\005\128\223\251alal\007\128\186\189\154\185y\181\187\189\183\185\004\128al\223\255\223\251\006\128\183\185\186\189y\181\188\189\185\189\005\128al\223\251\001\128alal\001\128#\132\191\251al\001\128alalal\003\128\185\185\186\185\182\185\005\132alal\223\251alal\005\128\152\185\153\185\184\189\006\128alalalalal\004\128\185\189\154\185\150\181\005\128\191\251alal\034\132al\223\251\001\128\001\128al\223\255\001\128al\254\255\219\247al\008\128\184\185\005\128\223\251al\221\251al\223\255\189\247al\008\128\151\181\008\132alalalalal\220\251al\008\128\184\189\006\128al\254\255\254\255\254\255\000\128alal\001\128\000\128alal\000\128\254\255\253\251alal\223\255\007\128\223alal\255\254\255\254alal\255\190\247\223\255\006\128\223\251\223\251alal\223\251alalal\223\255\006\128al\190\247al\254al\255\000\128alal\001\128\000\128al\223\255\000\128\253\255\253al\255\223\251\007\128\215\189\007\128\223\251\223\255\254\255\254alalal\255\007\128\214\189\004\128alalalal\255\251alal\007\128\181\185\004\128alalalal\000\128alal\034\132\000\128alal\001\128\253\255\254al\255\006\128\185\185\154\181\187\189\008\128\223alalal\255\223\251\007\132\186\189\154\185\182\185\005\128\223al\255\254\255alal\005\128\185\189\154\185\151\185\007\128\223alal\255\000\128\254\255\254\255!\132\000\128\254al\255\001\128alal\005\128\151\181\155\185\190\189\156\185\152\181\006\132\223\255\223al\255\006\128\151\185|\185\158\189\186\189\149\181\006\132\223\251\255\251al\004\128\182\185\155\185\190\189\155\185\185\189\008\132\223\255\223\251 \132\254\255\253\251\000\128\000\128\254al\255\001\128\223\255\007\132\153\185\188\189|\181\157\185{\181\186\189\183\189\006\128\223\255\006\128\185\189\189\189~\185~\185z\181\186\189\184\189\007\128\191\251\006\128\218\189\155\185\190\189\092\181\157\185\156\189v\181\006\128al\000\128\253\255\253\255!\132\000\128\254\255\221\251\034\132\004\128\149\181\187\189}\185\191\189\158\185\157\189\154\185\151\185\213\189\004\128\213\189\154\185|\181~\185\159\189\190\193\154\185\150\181\214\189\006\132\181\185\154\185\157\189|\185\158\185\191\193|\185\184\189\180\189\002\128\000\128\253\255\253\251\000\128\000\128\222al\255\000\128al\004\128\184\185\156\185}\181\159\185~\185{\185\149\185\004\132al\004\128\218\193|\185\159\189}\181|\181\186\189\213\189\003\128al\003\128\183\185\155\185\190\189~\185\127\185\157\185\183\189\004\128al\000\128\254\255\254\255!\132\001\128alal\000\128alal\006\128\185\185\156\185\190\189{\181\219\193\006\128\223\251alal\007\128\186\189\155\185z\181\188\193\184\189\004\128alalal\007\132v\177\154\185\188\189{\181\185\185\006\128\223\251\223\251\000\128alal\000\128\002\132alal\000\128al\255\251al\004\128\182\185\150\181\182\189\005\128\223\251alalal\223\251\005\128\149\185\216\189\215\189\006\128\223\251alalal\223\251\005\128\215\189\150\181\214\189\004\128\223al\255al\034\132alal\001\128\002\128\223\251al\000\128\000\128\000\128\000\128\001\128\004\128\005\128\003\128#\132\002\128\001\128\001\128!\132 \128\001\128\004\128\005\128\004\128\003\128\034\132\001\128\001\128\001\128\001\128\002\128\005\128\005\128\002\128\000\128\000\128\000\128!\132\000\128\223al\255\001\128\001\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\223\251al\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal!\132alalal\000\128\000\128\000\128!\132\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128!\132\000\128\000\128\000\128!\132alal")



cards = {}
for _=1, 4 do
	cards[_] = {}
	for __=1, 13 do
		cards[_][__] = {}
	end
end


cards[1][1].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\023\223\000\128\023\223alalalalalalalalalalalalalalalalalalalalalalal\023\223\000\128\023\223alalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalal\023\223\000\128J\169\000\128\023\223alalalalalalalalalalalalalalalalalalalalal\023\223\000\128J\169\000\128\023\223alalal\000\128\000\128alalal\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128alalal\000\128\000\128alal\155\239\000\128\000\128\000\128\000\128\000\128\155\239alalalalalalalalalalalalalalalalalalal\155\239\000\128\000\128\000\128\000\128\000\128\155\239alal\000\128\000\128alalJ\169\000\128\000\128\000\128\000\128\000\128J\169alalalalalalalalalalalalalalalalalalalJ\169\000\128\000\128\000\128\000\128\000\128J\169alal\000\128\000\128alal\000\128\000\128\155\239al\155\239\000\128\000\128alalalalalalalalalalalalalalalalalalal\000\128\000\128\155\239al\155\239\000\128\000\128alal\000\128\000\128alal\000\128J\169alalalJ\169\000\128alalalalalalalalalalalalalalalalalalal\000\128J\169alalalJ\169\000\128alal\000\128")
cards[1][1].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalR\202alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalz\235\000\128z\235alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalz\235\000\128\000\128\000\128z\235alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalz\235\000\128\000\128\000\128\000\128\000\128z\235alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalz\235\000\128\000\128\000\128\000\128\000\128\000\128\000\128z\235alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalk\173\000\128\000\128\000\128\000\128\000\128\000\128\000\128k\173alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalk\173k\173al\000\128alk\173k\173alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalz\235\000\128z\235alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalz\235\000\128\000\128\000\128z\235alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\023\223\000\128\023\223alalalalalalalalalalalalalalalalalalalalalalal\023\223\000\128\023\223alalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalal\023\223\000\128J\169\000\128\023\223alalalalalalalalalalalalalalalalalalalalal\023\223\000\128J\169\000\128\023\223alalal\000\128\000\128alalal\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128alalal\000\128\000\128alal\155\239\000\128\000\128\000\128\000\128\000\128\155\239alalalalalalalalalalalalalalalalalalal\155\239\000\128\000\128\000\128\000\128\000\128\155\239alal\000\128\000\128alalJ\169\000\128\000\128\000\128\000\128\000\128J\169alalalalalalalalalalalalalalalalalalalJ\169\000\128\000\128\000\128\000\128\000\128J\169alal\000\128\000\128alal\000\128\000\128\155\239al\155\239\000\128\000\128alalalalalalalalalalalalalalalalalalal\000\128\000\128\155\239al\155\239\000\128\000\128alal\000\128\000\128alal\000\128J\169alalalJ\169\000\128alalalalalalalalalalalalalalalalalalal\000\128J\169alalalJ\169\000\128alal\000\128\156\243\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\156\247\222\255\189\247\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128{\243al")
cards[1][2].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202c\140c\140c\140R\202alalalalalalalalalalz\235alalalalalalalalalalR\202c\140c\140c\140R\202alalal\000\128\000\128alalR\202c\140c\140c\140c\140c\140R\202alalalalalalalal\246\218\000\128\246\218alalalalalalalalR\202c\140c\140c\140c\140c\140R\202alal\000\128\000\128alalc\140c\140alal\023\223c\140c\140alalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalc\140c\140alal\023\223c\140c\140alal\000\128\000\128alalalalalalR\202c\140c\140alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalR\202c\140c\140alal\000\128\000\128alalalalalR\202c\140c\140alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalalR\202c\140c\140alalal\000\128\000\128alalalalR\202c\140c\140alalalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalR\202c\140c\140alalalal\000\128\000\128alalalR\202c\140c\140alalalalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalR\202c\140c\140alalalalal\000\128\000\128alalR\202\198\152c\140c\140c\140c\140c\140alalalalalalalalal\000\128alalalalalalalalalR\202\198\152c\140c\140c\140c\140c\140alal\000\128\000\128alalc\140c\140c\140c\140c\140c\140c\140alalalalalalalal\000\128\132\144\000\128alalalalalalalalc\140c\140c\140c\140c\140c\140c\140alal\000\128")
cards[1][2].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202c\140c\140c\140R\202alalalalalalalalalalz\235alalalalalalalalalalR\202c\140c\140c\140R\202alalal\000\128\000\128alalR\202c\140c\140c\140c\140c\140R\202alalalalalalalal\246\218\000\128\246\218alalalalalalalalR\202c\140c\140c\140c\140c\140R\202alal\000\128\000\128alalc\140c\140alal\023\223c\140c\140alalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalc\140c\140alal\023\223c\140c\140alal\000\128\000\128alalalalalalR\202c\140c\140alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalR\202c\140c\140alal\000\128\000\128alalalalalR\202c\140c\140alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalalR\202c\140c\140alalal\000\128\000\128alalalalR\202c\140c\140alalalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalR\202c\140c\140alalalal\000\128\000\128alalalR\202c\140c\140alalalalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalR\202c\140c\140alalalalal\000\128\000\128alalR\202\198\152c\140c\140c\140c\140c\140alalalalalalalalal\000\128alalalalalalalalalR\202\198\152c\140c\140c\140c\140c\140alal\000\128\000\128alalc\140c\140c\140c\140c\140c\140c\140alalalalalalalal\000\128\132\144\000\128alalalalalalalalc\140c\140c\140c\140c\140c\140c\140alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alal\133\148\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][3].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalalz\235alalalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\246\218\000\128\246\218alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalalalal\023\223J\169\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\023\223J\169\000\128\000\128alal\000\128\000\128alalalal\000\128\000\128\000\128\000\128alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128alalal\000\128\000\128alalalalal\023\223J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalal\023\223J\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128")
cards[1][3].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalz\235alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\000\128alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalalz\235alalalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\246\218\000\128\246\218alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalalalal\023\223J\169\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\023\223J\169\000\128\000\128alal\000\128\000\128alalalal\000\128\000\128\000\128\000\128alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128alalal\000\128\000\128alalalalal\023\223J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalal\023\223J\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][4].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalalalR\202\000\128alalalalalalalalalalz\235alalalalalalalalalalalalalR\202\000\128alalal\000\128\000\128alalalalalR\202\000\128\000\128alalalalalalalalal\246\218\000\128\246\218alalalalalalalalalalalR\202\000\128\000\128alalal\000\128\000\128alalalalR\202\000\128\000\128\000\128alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalalR\202\000\128\000\128\000\128alalal\000\128\000\128alalalR\202\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalR\202\000\128\000\128\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128al\000\128\000\128alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128al\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalalalal\000\128\000\128alalal\000\128")
cards[1][4].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalz\235alalalalalalalalalalalalalz\235alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalal\000\128\000\128alalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalR\202\000\128alalalalalalalalalalz\235alalalalalalalalalalalalalR\202\000\128alalal\000\128\000\128alalalalalR\202\000\128\000\128alalalalalalalalal\246\218\000\128\246\218alalalalalalalalalalalR\202\000\128\000\128alalal\000\128\000\128alalalalR\202\000\128\000\128\000\128alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalalR\202\000\128\000\128\000\128alalal\000\128\000\128alalalR\202\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalR\202\000\128\000\128\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128al\000\128\000\128alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128al\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalalalal\000\128\000\128alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][5].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalz\235alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\246\218\000\128\246\218alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalal\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalalalalJ\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalalalJ\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128")
cards[1][5].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalz\235alalalalalalalalalalalalz\235alalalalalalalalalalalalz\235alalalalal\000\128\000\128alalalal\246\218\000\128\246\218alalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalal\246\218\000\128\246\218alalalal\000\128\000\128alalal\246\218\000\128\000\128\000\128\246\218alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alal\000\128\000\128alalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\132\144\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalz\235alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\246\218\000\128\246\218alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalal\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalalalalJ\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalalalJ\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][6].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalJ\169\000\128\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalJ\169\000\128\000\128\000\128alalalal\000\128\000\128alalJ\169\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalJ\169\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128J\169\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128J\169\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alalal\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\155\251alalalalalalalalalalalalalalalalalal\000\128")
cards[1][6].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\000\128alalalalalalalalalalalalalalalalalal\000\128\000\128alalalJ\169\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128alalalal\000\128\000\128alalJ\169\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalJ\169\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128J\169\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128J\169\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alalal\000\128\000\128\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalal\000\128\000\128\000\128\000\128alalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][7].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalJ\169alalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalJ\169alalal\000\128\000\128alalal\000\128\000\128alalalalal\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128R\202alalal\000\128\000\128alalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalal\000\128\000\128alalalal\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128R\202alalalal\000\128\000\128alalalal\000\128\000\128alalalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalal\000\128\000\128alalalalal\000\128\000\128alalal\000\128\000\128R\202alalalalalalalalalalalal\000\128alalalalalalalalalal\000\128\000\128R\202alalalalal\000\128\000\128alalal\000\128\000\128\023\223alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\023\223alalalalal\000\128")
cards[1][7].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\000\128alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\000\128alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalJ\169alalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalJ\169alalal\000\128\000\128alalal\000\128\000\128alalalalal\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128R\202alalal\000\128\000\128alalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalal\000\128\000\128alalalal\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128R\202alalalal\000\128\000\128alalalal\000\128\000\128alalalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalal\000\128\000\128alalalalal\000\128\000\128alalal\000\128\000\128R\202alalalalalalalalalalalal\000\128alalalalalalalalalal\000\128\000\128R\202alalalalal\000\128\000\128alalal\000\128\000\128\023\223alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\023\223alalalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][8].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalalz\235alalalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\246\218\000\128\246\218alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\023\223al\023\223\000\128\000\128alalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalal\000\128\000\128\023\223al\023\223\000\128\000\128alal\000\128\000\128alal\000\128\000\128J\169\023\223J\169\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128J\169\023\223J\169\000\128\000\128alal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128J\169\023\223J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128J\169\023\223J\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128\023\223al\023\223\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128\023\223al\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128")
cards[1][8].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalz\235alalalalalalalalalalalalz\235alalalalalalalalalalalalz\235alalalalal\000\128\000\128alalalal\246\218\000\128\246\218alalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalal\246\218\000\128\246\218alalalal\000\128\000\128alalal\246\218\000\128\000\128\000\128\246\218alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alal\000\128\000\128alalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\132\144\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalz\235alalalalalalalalalalalalz\235alalalalalalalalalalalalz\235alalalalal\000\128\000\128alalalal\246\218\000\128\246\218alalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalal\246\218\000\128\246\218alalalal\000\128\000\128alalal\246\218\000\128\000\128\000\128\246\218alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alal\000\128\000\128alalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\132\144\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalalz\235alalalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\246\218\000\128\246\218alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\023\223al\023\223\000\128\000\128alalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalal\000\128\000\128\023\223al\023\223\000\128\000\128alal\000\128\000\128alal\000\128\000\128J\169\023\223J\169\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128J\169\023\223J\169\000\128\000\128alal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128J\169\023\223J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalal\000\128\000\128J\169\023\223J\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128\023\223al\023\223\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128\023\223al\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][9].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalalz\235alalalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\246\218\000\128\246\218alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\023\223alR\202\000\128\000\128alalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalal\000\128\000\128\023\223alR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128J\169alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128J\169alal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalal\023\223\000\128\000\128J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalal\023\223\000\128\000\128J\169\000\128\000\128alal\000\128\000\128alal\023\223alalalal\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\023\223alalalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalJ\169\000\128\000\128\000\128R\202alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalJ\169\000\128\000\128\000\128R\202alalal\000\128")
cards[1][9].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalz\235alalalalalalalalalalalalalz\235alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalal\000\128\000\128alalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\000\128alalalalz\235alalalalalalalalalalalalalz\235alalalalalalalalalalalalalz\235alalalal\000\128\000\128alalal\246\218\000\128\246\218alalalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalalal\246\218\000\128\246\218alalal\000\128\000\128alal\246\218\000\128\000\128\000\128\246\218alalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalal\246\218\000\128\000\128\000\128\246\218alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128al\000\128\000\128alR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202al\000\128\000\128alalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalal\000\128\000\128alalal\000\128\132\144\000\128alalalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalalal\000\128\132\144\000\128alalal\000\128\000\128alalalalalalalalalalalz\235alalalalalalalalalalalalalz\235alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalalal\246\218\000\128\246\218alalalalalalalalalal\000\128\000\128alalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalal\000\128\000\128alalalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalalz\235alalalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalal\246\218\000\128\246\218alalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\023\223alR\202\000\128\000\128alalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalal\000\128\000\128\023\223alR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128J\169alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128J\169alal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalR\202\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalal\023\223\000\128\000\128J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalal\023\223\000\128\000\128J\169\000\128\000\128alal\000\128\000\128alal\023\223alalalal\000\128\000\128alalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\023\223alalalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalJ\169\000\128\000\128\000\128R\202alalalalalalalalal\000\128\132\144\000\128alalalalalalalalalJ\169\000\128\000\128\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][10].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000al\252\251\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\252\251alal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202alalR\202\000\128R\202alalalalalalalalalalalalalalalalalalalR\202alalR\202\000\128R\202alalal\000\128\000\128alalR\202\000\128alR\202\000\128\000\128\000\128R\202alalalalalalalal\000\128alalalalalalalalR\202\000\128alR\202\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalalal\000\128\000\128\000\128alalalalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128\000\128R\202alalalalalalalal\000\128alalalalalalalal\000\128\000\128alR\202\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128alalR\202\000\128R\202alalalalalalalal\000\128\000\128\000\128alalalalalalal\000\128\000\128alalR\202\000\128R\202alalal\000\128")
cards[1][10].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalalalal\000\128\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202alalR\202\000\128R\202alalalalalalalalalalalalalalalalalalalR\202alalR\202\000\128R\202alalal\000\128\000\128alalR\202\000\128alR\202\000\128\000\128\000\128R\202alalalalalalalal\000\128alalalalalalalalR\202\000\128alR\202\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalalal\000\128\000\128\000\128alalalalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128\000\128R\202alalalalalalalal\000\128alalalalalalalal\000\128\000\128alR\202\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128alalR\202\000\128R\202alalalalalalalal\000\128\000\128\000\128alalalalalalal\000\128\000\128alalR\202\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][11].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalz\235alalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\246\218\000\128\246\218alalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalalal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128R\202alalalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alalalR\202\000\128\000\128R\202alalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalR\202\000\128\000\128R\202alalalal\000\128")
cards[1][11].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128al}\223C\208C\208\133\136\001\248\198\248\001\248\001\248\198\248C\132\197\216C\148\165\236\001\248\001\248\198\248C\208\198\148C\208\133\136\001\248\198\248\001\248C\188C\188alal\247\222\016\1949\231al<\227\000\128al\000\128\000\128al\000\128alalW\190\001\248C\188\198\148C\208\165\172C\148\133\136\133\136C\208\165\172C\148\198\148D\168\198\148C\148\165\236D\168\133\136\133\136\133\136\133\136\001\248\228\201f\210al\246\218\000\128\246\218al\009\201\000\128al\000\128\000\128al\000\128alalal\007\157\001\248C\208\165\172\001\248\165\236\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\198\248\001\248\001\248\001\248C\208\197\216\197\189al\023\223\000\128\000\128\000\128\024\227al\000\128al\000\128\000\128al\000\128alalalalD\168\001\248\001\248C\208C\188D\168\198\148C\148\133\136C\132\133\136\133\136\133\136\133\136C\132\133\136C\148\165\172D\168\165\200\203\185d\222al\000\128\000\128\000\128\000\128\000\128al\000\128al\000\128\000\128al\000\128alalalal\157\239C\132C\132C\132C\132C\132C\132C\132\133\136\198\148\133\136C\132\133\136C\132C\132C\132C\132C\132C\132C\132ald\222R\202\000\128\000\128\000\128\000\128\000\128R\202\000\128al\000\128\000\128al\000\128alalalal\157\239D\173\228\201d\222E\206d\222E\206\204\226alalalalalalalalalal\218\206k\218al\244\177\000\128\000\128\000\128\000\128\000\128\132\144\000\128\000\128al\000\128\000\128al\000\128alalalalW\190\228\201d\222E\206E\206E\206d\2225\227al\157\239v\202v\202\157\239alalal\248\218al}\223N\202alalR\202\000\128k\173\000\128k\173\008\161R\202\000\128al\000\128\000\128al\000\128alalalalj\161E\206d\222E\206E\206E\206\228\201alv\202}\223alalW\190al}\223v\202al\157\239\150\161N\202alalalalal\000\128alal(\206\000\128al\000\128\000\128al\000\128alalalal\206\176E\206d\222E\206E\206E\206\228\201alalv\2023\1573\157\157\239al\218\206\244\177P\128\208\148\218\206d\222alalalal\000\128\132\144c\140-\222\201\189\000\128al\000\128\000\128al\000\128alalalalD\173E\206E\206d\222d\222d\222\228\201al\218\206\244\177\150\161v\202\208\148alW\190W\190W\1903\157r\169k\218alalalalalalalD\173E\206\000\128al\000\128\000\128al\000\128alalal}\223D\173d\222d\222E\206\196\234d\222\228\201alal\218\206\244\1773\157alal\248\218al\244\177v\202s\218k\218alalalalalalal\197\189\228\201\000\128al\000\128\000\128al\000\128alalalW\190\228\201E\206d\222E\206\196\234E\206d\222\157\239alalalalalal\222\223\157\239alalk\218\196\234\218\206\157\239alalalal\157\239\228\201D\173\000\128al\000\128\000\128al\000\128alalW\190\228\213E\206\197\189d\222E\206\228\250E\206d\222\248\218alalal\218\206alalalv\202alal\203\185\228\201\228\201\197\189alalalalal\197\189\197\189\000\128al\000\128\000\128al\000\128alal\244\177\228\201d\222\196\234\228\201\228\201\228\250d\222d\222\204\226alalal\157\239v\202\248\218W\190alal\157\239\228\213}\223N\202\157\239alalalalal\228\201\007\157\000\128al\000\128\000\128al\000\128alalW\190\197\189\228\201\228\201d\222\196\234\197\189\228\250\228\2135\227alalalal\157\239\248\218W\190\157\239alW\190d\222al\218\2065\227alalalalalD\173\228\213\000\128al\000\128\000\128al\000\128v\202\007\157C\132\228\213D\173\197\189E\206\197\189\228\201D\173E\206\218\206alalal\218\206W\190v\202v\202v\202alD\173\228\201}\223d\222D\173alalalalal\197\189E\206\000\128al\000\128\000\128al\000\1289\227\145\210S\239\206\181\018\231p\206\020\227D\173\228\250E\206\228\201\248\218alalalalal\248\218alalJ\173\228\201\228\201\240\201D\173\197\189alalal}\223\240\201D\173E\206\000\128al\000\128\000\128al\000\128\189\247al\246\218\000\128\246\218r\251\147\206\197\189\197\189D\173W\190r\169\244\177\157\239alalalal}\223C\132\228\201\228\201\197\189\007\157\228\201\203\185al\157\239W\190\157\239al\157\239C\132\000\128al\000\128\000\128al\000\128al\246\218\000\128\000\128\000\128Z\235\141\226\133\136\228\201d\222\240\201\150\161W\190\208\148r\169\218\206\218\206\244\177P\128\203\185r\169\198\148j\161\157\239alalalW\190alW\190P\128\218\206\208\148\000\128al\000\128\000\128al\000\128al\000\128\000\128\000\128\000\128\000\128\214\214\228\201\196\234E\206\228\213c\251\240\201\228\250\228\201D\173\196\234W\1905\227\240\201j\161\157\239\228\213\007\157D\173N\202\244\177alal\177\136P\128r\169\218\206\000\128al\000\128\000\128al\000\128R\202\000\128\000\128\000\128\000\128\000\128R\202c\251c\251\007\157E\206\198\148\196\234C\132E\206\198\148\228\250W\190\240\201j\161\208\148\243\251v\202c\251\007\157d\222\228\201\157\239al\150\161P\128\208\148\218\206\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\132\144\000\128C\132d\222\197\189\133\136\228\250\196\234E\206\133\136\197\189k\218\240\201N\202W\190N\2025\227\196\234D\173\197\189\197\189\196\234\248\218al\208\148P\1283\157}\223\000\128al\000\128\000\128al\000\128R\202\000\128k\173\000\128k\173\000\128R\202\197\189C\132C\148\228\201c\251c\251c\251\197\189C\132\007\157\218\206N\202\203\185J\173\243\251\240\201\196\234\228\201D\173\196\234\204\226al\177\136\208\1483\157\218\206\000\128al\000\128\000\128al\000\128\148\206alal\000\128alal\144\230\196\234d\222D\173C\132C\132\197\189C\132C\132C\188C\208\204\226N\202\208\148P\128\243\251\243\251k\218\228\201D\173\196\234E\206\157\239W\190\208\148P\128\244\177\000\128al\000\128\000\128al\000\128\217\218al\000\128\132\144\000\128alN\226\196\234\197\189d\222E\206D\173C\132C\148\001\248\001\248C\2085\227\240\201N\202j\161\243\251v\202d\222D\173\228\201\007\157C\132C\132C\132\240\201\228\201\133\136\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalz\235alalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\246\218\000\128\246\218alalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalal\246\218\000\128\000\128\000\128\246\218alalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\132\144\000\128alalalalalalalalalal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalR\202\000\128k\173\000\128k\173\000\128R\202alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128R\202alalalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alalalR\202\000\128\000\128R\202alalalalalalalalalal\000\128\132\144\000\128alalalalalalalalalR\202\000\128\000\128R\202alalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][12].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202\000\128\000\128R\202alalalalalalalalalalalalalalalalalalalalalalR\202\000\128\000\128R\202alalalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128R\202alalalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128R\202\000\128\000\128J\169alalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalal\000\128\000\128R\202\000\128\000\128J\169alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128R\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128R\202\000\128\000\128alal\000\128")
cards[1][12].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128B\136B\136\165\148\132\144!\132!\132\231\156\000\128al\000\128\000\128al\000\128alalalalalalalal\165\200W\190W\190W\190al\218\206v\202\218\206\218\2063\157I\233\133\136C\188\001\248\165\200C\208c\251c\251\138\251alal\000\128alal\140\251\000\128al\000\128\000\128al\000\128alalalalalalal\157\239\165\200W\190\244\177\157\239alalv\202W\190\218\206\150\161\150\161\197\216\133\136\165\236\001\248C\208\165\200D\173k\225al\000\128\000\128\000\128al\203\230\000\128al\000\128\000\128al\000\128alalalalalalals\218D\205W\190alalalalal}\223\244\177W\190\208\148I\233C\148\133\136\001\248\198\148C\208\001\248al\000\128\000\128\000\128\000\128c\140al\000\128al\000\128\000\128al\000\128alalalalalalalL\209\197\189\222\223alalalal\218\206\248\218al}\223\177\136\244\177\001\248C\132C\188C\208D\168C\208\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalalalalalalC\188k\218al\244\177}\223alW\190\157\239\157\239v\202al\218\2063\157L\209C\188\133\136\165\236D\168C\208\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalalalalal}\223\197\216\203\185\208\1483\1573\157al}\223W\190W\190\157\239alal\177\136\150\161\198\248C\132\133\136\001\248D\168R\202\000\128J\169\000\128J\169c\140R\202\000\128al\000\128\000\128al\000\128alalalalalalL\209\228\237W\190P\128\244\177W\190alW\190P\128r\169\208\148}\223alr\169W\190L\209C\208C\132\165\200\001\248\174\213al)\165\000\128alalal\000\128al\000\128\000\128al\000\128alalalalalalC\208E\206W\190al\248\218\218\206alalv\202\244\177alalal\218\2063\157W\190\165\236C\148C\132\001\248R\214al1\198\000\128\000\128alal\000\128al\000\128\000\128al\000\128alalalalals\218C\208\197\189W\190al}\223alalalalalalalalal3\157\218\206W\190\001\248\133\136C\148C\208D\168C\208\165\172\165\200d\222al\000\128al\000\128\000\128al\000\128alalalalalC\208\228\237C\148W\190al\218\206alalalalalalalalal\244\177\244\177v\202L\209C\188C\132\197\216\001\248C\188D\205\229\251d\222\218\206\000\128al\000\128\000\128al\000\128alalalal\248\218\001\248d\222C\132\244\177al\218\206\157\239\218\206\244\177alalalalal\157\239\248\218\208\148\218\206W\190\198\248C\132C\132\001\248C\208C\208\228\201C\208)\249\000\128al\000\128\000\128al\000\128alalalalC\208\165\236\197\189C\132\133\136al\157\239\157\239alalalalalalal\157\239W\190\208\148W\190\218\206\208\213C\208\133\136C\148\198\248C\208C\208C\208C\188\000\128al\000\128\000\128al\000\128alalal\218\206\001\248\228\213\198\148\133\136C\132\157\239\248\218r\169\150\161\218\206alalalalal\244\177al\208\148\150\161\248\218\150\161\198\248C\148\133\136C\208C\208\244\177alal\000\128al\000\128\000\128al\000\128alalalC\208\001\248k\218\133\136C\148C\132\007\157al\248\218al\218\206\157\239alalalW\190\218\206\218\206\244\177\208\148W\190}\223\240\201\001\248C\132C\132\222\223alalal\000\128al\000\128\000\128al\000\128alal\240\201\001\248D\205D\173C\132C\148\133\136C\132\222\223\157\239\157\239alalalalW\190v\202\218\206\248\218\218\206P\128W\190\218\206W\190\198\248D\168C\132J\173alalal\000\128al\000\128\000\128al\000\128alalC\208\001\248\196\234C\132\133\136C\148C\132C\132\133\136alalal\248\218\218\206W\190\218\206v\202\218\206\218\206alP\128r\169\218\206\218\206W\190\001\248C\132C\132}\223alal\000\128al\000\128\000\128al\000\128alt\230l\249\238\229\205\222\206\177\141\185\198\148\133\136C\148C\132\133\136r\169\150\161\218\206\150\161W\190\244\177W\190W\190W\190\218\206P\128P\128W\190v\202W\190I\233C\208C\132\133\136alal\000\128al\000\128\000\128al\000\128\223\239alal\000\128al*\251p\255\228\250\228\250\228\250c\251\228\250\228\250\228\250\228\250\228\250\228\250\228\250\228\250c\251\228\250\228\250c\251f\2503\157v\202\218\206\244\177\001\248C\148C\132\203\185al\000\128al\000\128\000\128al\000\128\025\235al\000\128\000\128\000\128al\206\185\007\157D\173D\173\198\148D\173\007\157\197\189\133\136\197\189\133\136\228\201C\132D\173D\173\198\148D\173\007\157\007\157W\190\218\206v\202L\209\001\248\133\136C\132al\000\128al\000\128\000\128al\000\128\215\238c\140\000\128\000\128\000\128\000\128x\243\007\157\197\189\007\157D\173\007\157D\173\228\201\007\157d\222\198\148E\206J\173\197\189D\173D\173\197\189\007\157\198\148r\169\218\206\218\206\150\161\198\248D\168C\132\007\157\000\128al\000\128\000\128al\000\128\140\177c\140\000\128\000\128\000\128\000\128\000\128D\173D\173\197\189\197\189\228\201\228\201E\206\228\213E\206E\206\228\213d\222d\222d\222\196\234\228\250\196\234\196\234C\132W\190\218\206\218\206\206\176\001\248C\132\133\136\000\128al\000\128\000\128al\000\128\008\161\000\128\000\128\000\128\000\128\000\128\000\128C\148C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132}\223}\223}\223\240\201\001\248D\168\000\128al\000\128\000\128al\000\128\181\214\000\128J\169\000\128J\169\000\128s\206C\208\228\201D\173E\206d\222\007\157D\173E\206C\132D\173\228\201\228\201D\173D\173C\188C\208C\188\165\200\165\200\165\200J\173al\248\218}\223C\188\001\248\000\128al\000\128\000\128al\000\128\024\239alal\000\128alals\254C\188\228\201\197\189d\222\228\250D\173\228\250D\173\229\251\196\234d\222\007\157\229\251\165\172\001\248\198\248\001\248\001\248\001\248\001\248\177\1363\157al\222\223v\202\001\248\000\128al\000\128\000\128al\000\128t\210al\000\128\000\128\000\128al\174\253D\173\228\201j\161E\206\196\234\198\148c\251\133\136\228\201c\251\007\157\228\250D\173\001\248\001\248\001\248\001\248\198\248\001\248\177\136\177\136\177\136P\128P\128\196\234D\173\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202\000\128\000\128R\202alalalalalalalalalalalalalalalalalalalalalalR\202\000\128\000\128R\202alalalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128R\202alalalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128R\202\000\128\000\128J\169alalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalal\000\128\000\128R\202\000\128\000\128J\169alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128R\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128R\202\000\128\000\128alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[1][13].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\000\128\000\128alalalR\202\000\128alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128alalalR\202\000\128alal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128alR\202\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128alalalalal\000\128\000\128alal\000\128\000\128R\202\000\128\000\128alalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalal\000\128\000\128R\202\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalal\000\128\000\128alR\202\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alal\000\128")
cards[1][13].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalal\240\201\197\189c\251c\251c\251c\251\228\201c\251E\206c\251\229\251C\208\001\248\196\234c\251c\251E\206\228\250d\222c\251c\251\229\251D\205\026\223alal\000\128alalal\000\128al\000\128\000\128al\000\128alalalalC\188\165\236E\206c\251E\206c\251\196\234d\222\196\234\228\237\001\248\165\200\165\236E\206d\222c\251c\251\196\234l\251\196\234C\208C\188alal\000\128\000\128\000\128alal\000\128al\000\128\000\128al\000\128alalalalW\190C\188\001\248E\206E\206\228\213\197\189d\222E\206\197\216C\208\198\248C\208\228\213\196\234E\206\197\189d\222E\206\001\248C\188\218\206alc\140\000\128\000\128\000\128\000\128al\000\128al\000\128\000\128al\000\128alalalalalC\208C\208D\205\228\201E\206E\206\197\189\197\189C\188C\188\197\216C\188D\205\165\172\197\189J\173d\222\197\189\001\248C\188al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalalalal\248\218C\208C\188\007\157D\168D\168C\188D\168C\148\198\148C\132C\132C\132C\132C\132\133\136C\132C\132C\132v\202al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalalalalalC\148C\132\007\157\240\201N\202v\202\218\206s\218s\218N\202N\202\203\185J\173\007\157J\173\007\157J\173\007\157alalR\202\000\128J\169\000\128J\169\000\128R\202\000\128al\000\128\000\128al\000\128alalalalalal\244\177\248\218\157\239alalalalalalalal\157\239\248\218\157\239}\223}\223}\223\248\218alalalalal\000\128alal*\251\000\128al\000\128\000\128al\000\128alalalalalal\244\177\222\223al\157\239\218\206alW\190v\202W\190W\190\222\223al\248\218\218\206\157\239}\223\218\206\157\239}\223alalal\000\128\000\128\000\128al\009\251\000\128al\000\128\000\128al\000\128alalalalalal\208\148\157\239r\169v\202\218\206al\157\239}\223}\223al\248\218al}\223\157\239\218\206\157\239}\223}\223\248\218alalalalalal\157\239\228\250\000\128al\000\128\000\128al\000\128alalalalalal3\157v\202W\190W\190\248\218al\157\239\177\136\150\161\218\206alalalv\202\157\239\218\206\157\239\218\206}\223alalalalalal\157\239\228\250\000\128al\000\128\000\128al\000\128alalalalalalr\169\244\177\208\148\244\177v\202alW\190r\169\244\177\150\161alalal\218\206}\223\248\218}\223\248\218W\190alalalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalalW\190\150\161\248\218}\223\222\223\157\239alal\157\239}\223alalalal\218\206\218\206\218\206\218\206}\223W\190alalalalalal}\223c\251\000\128al\000\128\000\128al\000\128alalalalalv\2023\157alal\218\206alalalalalalalalal\248\218v\202\157\239\218\206\157\239v\202alalalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalal\157\239}\223\150\161\218\206alv\202\157\239\150\161W\190\248\218al}\223alal}\223\248\218\218\206}\223\248\218}\223\248\218\222\223alalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalv\202\218\206r\169}\223\157\239v\202\157\239al\244\177\150\161\157\239W\190alalv\202}\223}\223v\202}\223\218\206\248\218}\223alalalalal\157\239c\251\000\128al\000\128\000\128al\000\128alalalalal\218\206\248\218\244\177v\202\244\1773\157\208\148W\190\218\206\218\206\218\206al\157\239v\202\218\206\218\206}\223r\169\218\206v\202\244\177\218\206}\223alalal5\227l\251\000\128al\000\128\000\128al\000\128alalalalalalal\157\239alal\157\239\218\206alalalal}\223v\202W\190\218\206\248\218v\202\157\239}\223alalal\248\218\157\239alal\157\239l\251\000\128al\000\128\000\128al\000\128alalal\000\128al\026\223\158\231}\223alalalalalalal\218\206\218\206r\169\150\161W\190\248\218W\190\222\223\150\161v\202W\190W\190W\190\157\239alal}\223l\251\000\128al\000\128\000\128al\000\128alal\000\128\000\128\000\128al\217\210\218\206}\223\157\239\218\206\150\161\157\239}\223\248\218W\190\218\206\157\239\157\239\244\177\150\161\208\148C\188C\188\133\136C\148\177\1363\157alalal5\227l\251\000\128al\000\128\000\128al\000\128al\000\128\000\128\000\128\000\128!\132\092\231\248\218\248\218W\190\133\136C\208\206\176\150\161\150\161\150\161\150\161W\190\177\136D\168\001\248\001\248C\188\133\136C\148\001\248\001\248\001\248\206\176}\223al\157\239l\251\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\177\1363\157\244\177C\132C\132C\148C\208\165\236C\208\001\248\001\248\001\248\001\248C\188\133\136C\132\177\136\001\248\165\200C\208\133\136\001\248C\208\218\206\218\206\243\251\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128C\148j\161alP\128P\128\198\148C\132C\148C\208\001\248\001\248C\188\133\136C\132\007\157J\173\165\236C\208C\208\133\136\133\136C\208\228\250\228\201C\132\243\251\000\128al\000\128\000\128al\000\128R\202\000\128J\169\000\128J\169\000\128R\202\203\185C\132alD\173\229\251N\202P\128\133\136C\132C\148\133\136C\132J\173J\173d\222D\205\001\248C\208\001\248\133\136C\188D\205\228\250C\132\198\148\243\251\000\128al\000\128\000\128al\000\128[\235alal\000\128alalX\235C\132C\132v\202\204\226d\222\228\213\228\250l\251P\128\133\136\198\148P\128\196\234\196\234E\206\001\248C\208\001\248\198\248\001\248\001\248c\251\133\136\203\185C\132\243\251\000\128al\000\128\000\128al\000\1287\231al\000\128\000\128\000\128al\173\177J\173\007\157\198\148alD\173\196\234f\250E\206\228\213l\251\196\234\228\213\228\213\228\250\197\216C\208\165\236\001\248\001\248\001\248D\205d\222J\173r\169\198\148\243\251\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\000\128\000\128alalalR\202\000\128alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128alalalR\202\000\128alal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128alR\202\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128alalalalal\000\128\000\128alal\000\128\000\128R\202\000\128\000\128alalalalalalalalR\202\000\128J\169\000\128J\169\000\128R\202alalalalalal\000\128\000\128R\202\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalal\000\128\000\128alR\202\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][1].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\023\223\000\128\023\223alalalalalalalalalalalalalalalalalalalalalalal\023\223\000\128\023\223alalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalal\023\223\000\128J\169\000\128\023\223alalalalalalalalalalalalalalalalalalalalal\023\223\000\128J\169\000\128\023\223alalal\000\128\000\128alalal\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128alalal\000\128\000\128alal\155\239\000\128\000\128\000\128\000\128\000\128\155\239alalalalalalalalalalalalalalalalalalal\155\239\000\128\000\128\000\128\000\128\000\128\155\239alal\000\128\000\128alalJ\169\000\128\000\128\000\128\000\128\000\128J\169alalalalalalalalalalalalalalalalalalalJ\169\000\128\000\128\000\128\000\128\000\128J\169alal\000\128\000\128alal\000\128\000\128\155\239al\155\239\000\128\000\128alalalalalalalalalalalalalalalalalalal\000\128\000\128\155\239al\155\239\000\128\000\128alal\000\128\000\128alal\000\128J\169alalalJ\169\000\128alalalalalalalalalalalalalalalalalalal\000\128J\169alalalJ\169\000\128alal\000\128")
cards[2][1].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalk\173k\173k\173alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalk\173\000\128\000\128\000\128k\173alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalk\173\000\128\000\128al\000\128al\000\128\000\128k\173alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalk\173\000\128\000\128al\000\128al\000\128\000\128k\173alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalk\173k\173al\000\128alk\173k\173alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalz\235\000\128z\235alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalz\235\000\128\000\128\000\128z\235alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\023\223\000\128\023\223alalalalalalalalalalalalalalalalalalalalalalal\023\223\000\128\023\223alalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalal\023\223\000\128J\169\000\128\023\223alalalalalalalalalalalalalalalalalalalalal\023\223\000\128J\169\000\128\023\223alalal\000\128\000\128alalal\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128alalal\000\128\000\128alal\155\239\000\128\000\128\000\128\000\128\000\128\155\239alalalalalalalalalalalalalalalalalalal\155\239\000\128\000\128\000\128\000\128\000\128\155\239alal\000\128\000\128alalJ\169\000\128\000\128\000\128\000\128\000\128J\169alalalalalalalalalalalalalalalalalalalJ\169\000\128\000\128\000\128\000\128\000\128J\169alal\000\128\000\128alal\000\128\000\128\155\239al\155\239\000\128\000\128alalalalalalalalalalalalalalalalalalal\000\128\000\128\155\239al\155\239\000\128\000\128alal\000\128\000\128alal\000\128J\169alalalJ\169\000\128alalalalalalalalalalalalalalalalalalal\000\128J\169alalalJ\169\000\128alal\000\128\156\243\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\156\247\222\255\189\247\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128{\243al")
cards[2][2].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202c\140c\140c\140R\202alalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202c\140c\140c\140R\202alalal\000\128\000\128alalR\202c\140c\140c\140c\140c\140R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202c\140c\140c\140c\140c\140R\202alal\000\128\000\128alalc\140c\140alal\023\223c\140c\140alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalc\140c\140alal\023\223c\140c\140alal\000\128\000\128alalalalalalR\202c\140c\140alalalalalalalal1\198\000\1281\198alalalalalalalalalalalalR\202c\140c\140alal\000\128\000\128alalalalalR\202c\140c\140alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalR\202c\140c\140alalal\000\128\000\128alalalalR\202c\140c\140alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalR\202c\140c\140alalalal\000\128\000\128alalalR\202c\140c\140alalalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalR\202c\140c\140alalalalal\000\128\000\128alalR\202\198\152c\140c\140c\140c\140c\140alalalalalalalalal\000\128alalalalalalalalalR\202\198\152c\140c\140c\140c\140c\140alal\000\128\000\128alalc\140c\140c\140c\140c\140c\140c\140alalalalalalalal\000\128\000\128\000\128alalalalalalalalc\140c\140c\140c\140c\140c\140c\140alal\000\128")
cards[2][2].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202c\140c\140c\140R\202alalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202c\140c\140c\140R\202alalal\000\128\000\128alalR\202c\140c\140c\140c\140c\140R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202c\140c\140c\140c\140c\140R\202alal\000\128\000\128alalc\140c\140alal\023\223c\140c\140alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalc\140c\140alal\023\223c\140c\140alal\000\128\000\128alalalalalalR\202c\140c\140alalalalalalalal1\198\000\1281\198alalalalalalalalalalalalR\202c\140c\140alal\000\128\000\128alalalalalR\202c\140c\140alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalR\202c\140c\140alalal\000\128\000\128alalalalR\202c\140c\140alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalR\202c\140c\140alalalal\000\128\000\128alalalR\202c\140c\140alalalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalR\202c\140c\140alalalalal\000\128\000\128alalR\202\198\152c\140c\140c\140c\140c\140alalalalalalalalal\000\128alalalalalalalalalR\202\198\152c\140c\140c\140c\140c\140alal\000\128\000\128alalc\140c\140c\140c\140c\140c\140c\140alalalalalalalal\000\128\000\128\000\128alalalalalalalalc\140c\140c\140c\140c\140c\140c\140alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alal\133\148\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][3].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalalalal\023\223J\169\000\128\000\128alalalalalalalal1\198\000\1281\198alalalalalalalalalalal\023\223J\169\000\128\000\128alal\000\128\000\128alalalal\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128alalal\000\128\000\128alalalalal\023\223J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\023\223J\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128")
cards[2][3].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal1\198\000\1281\198alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\000\128alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalalalal\023\223J\169\000\128\000\128alalalalalalalal1\198\000\1281\198alalalalalalalalalalal\023\223J\169\000\128\000\128alal\000\128\000\128alalalal\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128alalal\000\128\000\128alalalalal\023\223J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\023\223J\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][4].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalalalR\202\000\128alalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalalR\202\000\128alalal\000\128\000\128alalalalalR\202\000\128\000\128alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalalR\202\000\128\000\128alalal\000\128\000\128alalalalR\202\000\128\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalalR\202\000\128\000\128\000\128alalal\000\128\000\128alalalR\202\000\128\000\128\000\128\000\128alalalalalalalalal1\198\000\1281\198alalalalalalalalalR\202\000\128\000\128\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128al\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalR\202\000\128\000\128al\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalalal\000\128\000\128alalal\000\128")
cards[2][4].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\000\128\000\128alalalalalalalalalal1\198\000\1281\198alalalalalalalalalalal1\198\000\1281\198alalalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalR\202\000\128alalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalalR\202\000\128alalal\000\128\000\128alalalalalR\202\000\128\000\128alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalalR\202\000\128\000\128alalal\000\128\000\128alalalalR\202\000\128\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalalR\202\000\128\000\128\000\128alalal\000\128\000\128alalalR\202\000\128\000\128\000\128\000\128alalalalalalalalal1\198\000\1281\198alalalalalalalalalR\202\000\128\000\128\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128al\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalR\202\000\128\000\128al\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalalal\000\128\000\128alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][5].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalJ\169\000\128J\169alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalalalalJ\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalJ\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128")
cards[2][5].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalal\000\128\000\128alalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalal\000\128\000\128alalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalal\000\128\000\128alalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalJ\169\000\128J\169alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalalalalJ\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalJ\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128alal\023\223\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128alal\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][6].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalJ\169\000\128\000\128\000\128alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128alalalal\000\128\000\128alalJ\169\000\128\000\128\000\128\000\128\000\128alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalJ\169\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alalalalalalalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128J\169\000\128\000\128alalalalalalalalJ\169\000\128\024\227\000\128\024\227\000\128J\169alalalalalal\000\128\000\128J\169\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128J\169\000\128J\169\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alalal\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\155\251alalalalalalalalalalalalalalalalalal\000\128")
cards[2][6].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalJ\169\000\128\024\227\000\128\024\227\000\128J\169alalalalalalalJ\169\000\128\024\227\000\128\024\227\000\128J\169alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128J\169\000\128J\169\000\128\000\128alalalalalalal\000\128\000\128J\169\000\128J\169\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalJ\169\000\128\024\227\000\128\024\227\000\128J\169alalalalalalalJ\169\000\128\024\227\000\128\024\227\000\128J\169alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128J\169\000\128J\169\000\128\000\128alalalalalalal\000\128\000\128J\169\000\128J\169\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalalalalalalal\000\128\000\128alalalJ\169\000\128\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128alalalal\000\128\000\128alalJ\169\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalJ\169\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alalalalalalalalalalalJ\169\000\128\024\227\000\128\024\227\000\128J\169alalalalalal\000\128\000\128alalalalalalal\000\128\000\128alal\000\128\000\128J\169\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128J\169\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128J\169\000\128J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalalal\000\128alalalalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alalal\000\128\000\128\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalal\000\128\000\128\000\128\000\128alalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][7].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalJ\169\000\128J\169alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalJ\169alalal\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalJ\169alalal\000\128\000\128alalal\000\128\000\128alalalalal\000\128\000\128R\202alalalalalalalalal1\198\000\1281\198alalalalalalalalalalal\000\128\000\128R\202alalal\000\128\000\128alalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalal\000\128\000\128alalalal\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128R\202alalalal\000\128\000\128alalalal\000\128\000\128alalalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalal\000\128\000\128alalalalal\000\128\000\128alalal\000\128\000\128R\202alalalalalalalalalalalal\000\128alalalalalalalalalal\000\128\000\128R\202alalalalal\000\128\000\128alalal\000\128\000\128\023\223alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\023\223alalalalal\000\128")
cards[2][7].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\000\128\000\128alalalalalalalalalal1\198\000\1281\198alalalalalalalalalalal1\198\000\1281\198alalalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal1\198\000\1281\198alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\000\128alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\000\128\000\128alalalalalalalalalal1\198\000\1281\198alalalalalalalalalalal1\198\000\1281\198alalalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalJ\169\000\128J\169alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalJ\169alalal\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalJ\169alalal\000\128\000\128alalal\000\128\000\128alalalalal\000\128\000\128R\202alalalalalalalalal1\198\000\1281\198alalalalalalalalalalal\000\128\000\128R\202alalal\000\128\000\128alalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalal\000\128\000\128alalalal\000\128\000\128R\202alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128R\202alalalal\000\128\000\128alalalal\000\128\000\128alalalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalal\000\128\000\128alalalalal\000\128\000\128alalal\000\128\000\128R\202alalalalalalalalalalalal\000\128alalalalalalalalalal\000\128\000\128R\202alalalalal\000\128\000\128alalal\000\128\000\128\023\223alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\023\223alalalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][8].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\023\223al\023\223\000\128\000\128alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128\023\223al\023\223\000\128\000\128alal\000\128\000\128alal\000\128\000\128J\169\023\223J\169\000\128\000\128alalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128J\169\023\223J\169\000\128\000\128alal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128J\169\023\223J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128J\169\023\223J\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128\023\223al\023\223\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128\023\223al\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128")
cards[2][8].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalal\000\128\000\128alalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalal\000\128\000\128alalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalal\000\128\000\128alalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalal\000\128\000\128alalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalal\000\128\000\128alalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalal\000\128\000\128alalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\023\223al\023\223\000\128\000\128alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128\023\223al\023\223\000\128\000\128alal\000\128\000\128alal\000\128\000\128J\169\023\223J\169\000\128\000\128alalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128J\169\023\223J\169\000\128\000\128alal\000\128\000\128alalal\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128alalal\000\128\000\128alal\000\128\000\128J\169\023\223J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128J\169\023\223J\169\000\128\000\128alal\000\128\000\128alal\000\128\000\128\023\223al\023\223\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128\023\223al\023\223\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][9].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\023\223alR\202\000\128\000\128alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128\023\223alR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128J\169alal\000\128\000\128alalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128J\169alal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalR\202\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalal\023\223\000\128\000\128J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\023\223\000\128\000\128J\169\000\128\000\128alal\000\128\000\128alal\023\223alalalal\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\023\223alalalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalJ\169\000\128\000\128\000\128R\202alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128R\202alalal\000\128")
cards[2][9].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\000\128\000\128alalalalalalalalalal1\198\000\1281\198alalalalalalalalalalal1\198\000\1281\198alalalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalal\000\128\000\128alalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alal\000\128\000\128alal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alal\000\128\000\128alalal1\198\000\1281\198alalalalalalalalalalal1\198\000\1281\198alalalalalalalalalalal1\198\000\1281\198alalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198al\000\128\000\128alalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalal\000\128\000\128alalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalal\000\128\000\128alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalal\000\128\000\128alalalalalalalalalal1\198\000\1281\198alalalalalalalalalalal1\198\000\1281\198alalalalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202\000\128\000\128\000\128R\202alalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202\000\128\000\128\000\128R\202alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128\023\223alR\202\000\128\000\128alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128\023\223alR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128J\169alal\000\128\000\128alalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128J\169alal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalR\202\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalal\023\223\000\128\000\128J\169\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalal\023\223\000\128\000\128J\169\000\128\000\128alal\000\128\000\128alal\023\223alalalal\000\128\000\128alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\023\223alalalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalJ\169\000\128\000\128\000\128R\202alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalJ\169\000\128\000\128\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][10].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000al\252\251\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\252\251alal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202alalR\202\000\128R\202alalalalalalalalJ\169\000\128J\169alalalalalalalalR\202alalR\202\000\128R\202alalal\000\128\000\128alalR\202\000\128alR\202\000\128\000\128\000\128R\202alalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalR\202\000\128alR\202\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalalal1\198\000\1281\198alalalalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128\000\128R\202alalalalalalalal\000\128alalalalalalalal\000\128\000\128alR\202\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128alalR\202\000\128R\202alalalalalalalal\000\128\000\128\000\128alalalalalalal\000\128\000\128alalR\202\000\128R\202alalal\000\128")
cards[2][10].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalal\000\128\000\128alalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalal\000\128\000\128alalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalal\000\128\000\128alalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalJ\169\000\128J\169alalalalalalalalalJ\169\000\128J\169alalalalalalalalalalal\000\128\000\128alalalalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalalal\000\128\000\128alalalalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalalal\000\128\000\128alalalalalalalalalalal1\198\000\1281\198alalalalalalalalal1\198\000\1281\198alalalalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128alalalalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalalalalal\000\128\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128alalalalalalalalalalal\000\128\000\128alalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalalJ\169\000\128J\169alalalal\000\128\000\128alalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalJ\169\000\128\000\128\000\128J\169alalal\000\128\000\128alalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalal\000\128\000\128alalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalalalalalalalal1\198\000\1281\198alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alal\000\128\000\128alalalalal\000\128alalalalalalalalalalalal\000\128alalalalalalalalalalalal\000\128alalalalal\000\128\000\128alalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128\000\128alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202alalR\202\000\128R\202alalalalalalalalJ\169\000\128J\169alalalalalalalalR\202alalR\202\000\128R\202alalal\000\128\000\128alalR\202\000\128alR\202\000\128\000\128\000\128R\202alalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalR\202\000\128alR\202\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalalalal1\198\000\1281\198alalalalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128al\000\128\000\128al\000\128\000\128alalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalal\000\128\000\128al\000\128\000\128al\000\128\000\128alal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128\000\128R\202alalalalalalalal\000\128alalalalalalalal\000\128\000\128alR\202\000\128\000\128\000\128R\202alal\000\128\000\128alal\000\128\000\128alalR\202\000\128R\202alalalalalalalal\000\128\000\128\000\128alalalalalalal\000\128\000\128alalR\202\000\128R\202alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][11].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalal1\198\000\1281\198alalalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128R\202alalalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alalalR\202\000\128\000\128R\202alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128R\202alalalal\000\128")
cards[2][11].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128al}\223C\208C\208\133\136\001\248\198\248\001\248\001\248\198\248C\132\197\216C\148\165\236\001\248\001\248\198\248C\208\198\148C\208\133\136\001\248\198\248\001\248C\188C\188alal1\198\000\1281\198al\218\206\000\128al\000\128\000\128al\000\128alalW\190\001\248C\188\198\148C\208\165\172C\148\133\136\133\136C\208\165\172C\148\198\148D\168\198\148C\148\165\236D\168\133\136\133\136\133\136\133\136\001\248\228\201E\206al\000\128\000\128\000\128alC\188\000\128al\000\128\000\128al\000\128alalal\007\157\001\248C\208\165\172\001\248\165\236\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\198\248\001\248\001\248\001\248C\208\197\216\197\189alal\023\223\000\128\023\223alal\000\128al\000\128\000\128al\000\128alalalalD\168\001\248\001\248C\208C\188D\168\198\148C\148\133\136C\132\133\136\133\136\133\136\133\136C\132\133\136C\148\165\172D\168\165\200\203\185d\222al\000\128\000\128\000\128\000\128\000\128al\000\128al\000\128\000\128al\000\128alalalal\157\239C\132C\132C\132C\132C\132C\132C\132\133\136\198\148\133\136C\132\133\136C\132C\132C\132C\132C\132C\132C\132ald\222al\000\128\000\128\000\128\000\128\000\128al\000\128al\000\128\000\128al\000\128alalalal\157\239D\173\228\201d\222E\206d\222E\206\204\226alalalalalalalalalal\218\206k\218al\244\177\228\201alal\000\128alalD\173\000\128al\000\128\000\128al\000\128alalalalW\190\228\201d\222E\206E\206E\206d\2225\227al\157\239v\202v\202\157\239alalal\248\218al}\223N\202alal\218\206al\000\128\000\128\000\128alD\173\000\128al\000\128\000\128al\000\128alalalalj\161E\206d\222E\206E\206E\206\228\201alv\202}\223alalW\190al}\223v\202al\157\239\150\161N\202alalalalalalalal\228\201\000\128al\000\128\000\128al\000\128alalalal\206\176E\206d\222E\206E\206E\206\228\201alalv\2023\1573\157\157\239al\218\206\244\177P\128\208\148\218\206d\222alalalalalalalD\205D\173\000\128al\000\128\000\128al\000\128alalalalD\173E\206E\206d\222d\222d\222\228\201al\218\206\244\177\150\161v\202\208\148alW\190W\190W\1903\157r\169k\218alalalalalalalD\173E\206\000\128al\000\128\000\128al\000\128alalal}\223D\173d\222d\222E\206\196\234d\222\228\201alal\218\206\244\1773\157alal\248\218al\244\177v\202s\218k\218alalalalalalal\197\189\228\201\000\128al\000\128\000\128al\000\128alalalW\190\228\201E\206d\222E\206\196\234E\206d\222\157\239alalalalalal\222\223\157\239alalk\218\196\234\218\206\157\239alalalal\157\239\228\201D\173\000\128al\000\128\000\128al\000\128alalW\190\228\213E\206\197\189d\222E\206\228\250E\206d\222\248\218alalal\218\206alalalv\202alal\203\185\228\201\228\201\197\189alalalalal\197\189\197\189\000\128al\000\128\000\128al\000\128alal\244\177\228\201d\222\196\234\228\201\228\201\228\250d\222d\222\204\226alalal\157\239v\202\248\218W\190alal\157\239\228\213}\223N\202\157\239alalalalal\228\201\007\157\000\128al\000\128\000\128al\000\128alalW\190\197\189\228\201\228\201d\222\196\234\197\189\228\250\228\2135\227alalalal\157\239\248\218W\190\157\239alW\190d\222al\218\2065\227alalalalalD\173\228\213\000\128al\000\128\000\128al\000\128v\202\007\157C\132\228\213D\173\197\189E\206\197\189\228\201D\173E\206\218\206alalal\218\206W\190v\202v\202v\202alD\173\228\201}\223d\222D\173alalalalal\197\189E\206\000\128al\000\128\000\128al\000\128C\132D\173d\222C\132k\218D\173\197\189D\173\228\250E\206\228\201\248\218alalalalal\248\218alalJ\173\228\201\228\201\240\201D\173\197\189alalal}\223\240\201D\173E\206\000\128al\000\128\000\128al\000\128C\132\197\189alalal\228\250\007\157\197\189\197\189D\173W\190r\169\244\177\157\239alalalal}\223C\132\228\201\228\201\197\189\007\157\228\201\203\185al\157\239W\190\157\239al\157\239C\132\000\128al\000\128\000\128al\000\128C\132al1\198\000\1281\198al\228\213\133\136\228\201d\222\240\201\150\161W\190\208\148r\169\218\206\218\206\244\177P\128\203\185r\169\198\148j\161\157\239alalalW\190alW\190P\128\218\206\208\148\000\128al\000\128\000\128al\000\128C\132al\000\128\000\128\000\128al\198\148\228\201\196\234E\206\228\213c\251\240\201\228\250\228\201D\173\196\234W\1905\227\240\201j\161\157\239\228\213\007\157D\173N\202\244\177alal\177\136P\128r\169\218\206\000\128al\000\128\000\128al\000\128alal\023\223\000\128\023\223alalc\251c\251\007\157E\206\198\148\196\234C\132E\206\198\148\228\250W\190\240\201j\161\208\148\243\251v\202c\251\007\157d\222\228\201\157\239al\150\161P\128\208\148\218\206\000\128al\000\128\000\128al\000\128al\000\128\000\128\000\128\000\128\000\128alC\132d\222\197\189\133\136\228\250\196\234E\206\133\136\197\189k\218\240\201N\202W\190N\2025\227\196\234D\173\197\189\197\189\196\234\248\218al\208\148P\1283\157}\223\000\128al\000\128\000\128al\000\128al\000\128\000\128\000\128\000\128\000\128al\197\189C\132C\148\228\201c\251c\251c\251\197\189C\132\007\157\218\206N\202\203\185J\173\243\251\240\201\196\234\228\201D\173\196\234\204\226al\177\136\208\1483\157\218\206\000\128al\000\128\000\128al\000\128\133\136alal\000\128alalD\205\196\234d\222D\173C\132C\132\197\189C\132C\132C\188C\208\204\226N\202\208\148P\128\243\251\243\251k\218\228\201D\173\196\234E\206\157\239W\190\208\148P\128\244\177\000\128al\000\128\000\128al\000\128r\169al\000\128\000\128\000\128alD\205\196\234\197\189d\222E\206D\173C\132C\148\001\248\001\248C\2085\227\240\201N\202j\161\243\251v\202d\222D\173\228\201\007\157C\132C\132C\132\240\201\228\201\133\136\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalalJ\169\000\128J\169alalalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalal\000\128\000\128\000\128\000\128\000\128alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalalal\000\128\000\128\000\128\000\128\000\128alal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalalalal1\198\000\1281\198alalalalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalal\000\128\000\128alalalalalal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128R\202alalalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alalalR\202\000\128\000\128R\202alalalalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128R\202alalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][12].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalR\202\000\128\000\128R\202alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202\000\128\000\128R\202alalalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128R\202alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128R\202\000\128\000\128J\169alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128R\202\000\128\000\128J\169alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128R\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128R\202\000\128\000\128alal\000\128")
cards[2][12].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalalalalalalal\165\200W\190W\190W\190al\218\206v\202\218\206\218\2063\157I\233\133\136C\188\001\248\165\200C\208c\251c\251c\251al1\198\000\1281\198alc\251\000\128al\000\128\000\128al\000\128alalalalalalal\157\239\165\200W\190\244\177\157\239alalv\202W\190\218\206\150\161\150\161\197\216\133\136\165\236\001\248C\208\165\200D\173C\208al\000\128\000\128\000\128ald\222\000\128al\000\128\000\128al\000\128alalalalalalals\218D\205W\190alalalalal}\223\244\177W\190\208\148I\233C\148\133\136\001\248\198\148C\208\001\248alal\023\223\000\128\023\223alal\000\128al\000\128\000\128al\000\128alalalalalalalL\209\197\189\222\223alalalal\218\206\248\218al}\223\177\136\244\177\001\248C\132C\188C\208D\168C\208al\000\128\000\128\000\128\000\128\000\128al\000\128al\000\128\000\128al\000\128alalalalalalalC\188k\218al\244\177}\223alW\190\157\239\157\239v\202al\218\2063\157L\209C\188\133\136\165\236D\168C\208al\000\128\000\128\000\128\000\128\000\128al\000\128al\000\128\000\128al\000\128alalalalalal}\223\197\216\203\185\208\1483\1573\157al}\223W\190W\190\157\239alal\177\136\150\161\198\248C\132\133\136\001\248D\168C\208alal\000\128alalal\000\128al\000\128\000\128al\000\128alalalalalalL\209\228\237W\190P\128\244\177W\190alW\190P\128r\169\208\148}\223alr\169W\190L\209C\208C\132\165\200\001\248C\188al\000\128\000\128\000\128alal\000\128al\000\128\000\128al\000\128alalalalalalC\208E\206W\190al\248\218\218\206alalv\202\244\177alalal\218\2063\157W\190\165\236C\148C\132\001\248\165\172alalalalalal\000\128al\000\128\000\128al\000\128alalalalals\218C\208\197\189W\190al}\223alalalalalalalalal3\157\218\206W\190\001\248\133\136C\148C\208D\168C\208\165\172\165\200d\222al\000\128al\000\128\000\128al\000\128alalalalalC\208\228\237C\148W\190al\218\206alalalalalalalalal\244\177\244\177v\202L\209C\188C\132\197\216\001\248C\188D\205\229\251d\222\218\206\000\128al\000\128\000\128al\000\128alalalal\248\218\001\248d\222C\132\244\177al\218\206\157\239\218\206\244\177alalalalal\157\239\248\218\208\148\218\206W\190\198\248C\132C\132\001\248C\208C\208\228\201C\208)\249\000\128al\000\128\000\128al\000\128alalalalC\208\165\236\197\189C\132\133\136al\157\239\157\239alalalalalalal\157\239W\190\208\148W\190\218\206\208\213C\208\133\136C\148\198\248C\208C\208C\208C\188\000\128al\000\128\000\128al\000\128alalal\218\206\001\248\228\213\198\148\133\136C\132\157\239\248\218r\169\150\161\218\206alalalalal\244\177al\208\148\150\161\248\218\150\161\198\248C\148\133\136C\208C\208\244\177alal\000\128al\000\128\000\128al\000\128alalalC\208\001\248k\218\133\136C\148C\132\007\157al\248\218al\218\206\157\239alalalW\190\218\206\218\206\244\177\208\148W\190}\223\240\201\001\248C\132C\132\222\223alalal\000\128al\000\128\000\128al\000\128alal\240\201\001\248D\205D\173C\132C\148\133\136C\132\222\223\157\239\157\239alalalalW\190v\202\218\206\248\218\218\206P\128W\190\218\206W\190\198\248D\168C\132J\173alalal\000\128al\000\128\000\128al\000\128alalC\208\001\248\196\234C\132\133\136C\148C\132C\132\133\136alalal\248\218\218\206W\190\218\206v\202\218\206\218\206alP\128r\169\218\206\218\206W\190\001\248C\132C\132}\223alal\000\128al\000\128\000\128al\000\128alL\209\001\248\197\216E\206\133\136C\148\198\148\133\136C\148C\132\133\136r\169\150\161\218\206\150\161W\190\244\177W\190W\190W\190\218\206P\128P\128W\190v\202W\190I\233C\208C\132\133\136alal\000\128al\000\128\000\128al\000\128\222\223\001\248alalal\228\250\228\250\228\250\228\250\228\250c\251\228\250\228\250\228\250\228\250\228\250\228\250\228\250\228\250c\251\228\250\228\250c\251f\2503\157v\202\218\206\244\177\001\248C\148C\132\203\185al\000\128al\000\128\000\128al\000\128\240\201al1\198\000\1281\198al\007\157\007\157D\173D\173\198\148D\173\007\157\197\189\133\136\197\189\133\136\228\201C\132D\173D\173\198\148D\173\007\157\007\157W\190\218\206v\202L\209\001\248\133\136C\132al\000\128al\000\128\000\128al\000\128L\209al\000\128\000\128\000\128al\228\201\007\157\197\189\007\157D\173\007\157D\173\228\201\007\157d\222\198\148E\206J\173\197\189D\173D\173\197\189\007\157\198\148r\169\218\206\218\206\150\161\198\248D\168C\132\007\157\000\128al\000\128\000\128al\000\128alal\023\223\000\128\023\223alalD\173D\173\197\189\197\189\228\201\228\201E\206\228\213E\206E\206\228\213d\222d\222d\222\196\234\228\250\196\234\196\234C\132W\190\218\206\218\206\206\176\001\248C\132\133\136\000\128al\000\128\000\128al\000\128al\000\128\000\128\000\128\000\128\000\128alC\148C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132}\223}\223}\223\240\201\001\248D\168\000\128al\000\128\000\128al\000\128al\000\128\000\128\000\128\000\128\000\128alC\208\228\201D\173E\206d\222\007\157D\173E\206C\132D\173\228\201\228\201D\173D\173C\188C\208C\188\165\200\165\200\165\200J\173al\248\218}\223C\188\001\248\000\128al\000\128\000\128al\000\128C\188alal\000\128alal\001\248C\188\228\201\197\189d\222\228\250D\173\228\250D\173\229\251\196\234d\222\007\157\229\251\165\172\001\248\198\248\001\248\001\248\001\248\001\248\177\1363\157al\222\223v\202\001\248\000\128al\000\128\000\128al\000\128C\148al\000\128\000\128\000\128al\001\248D\173\228\201j\161E\206\196\234\198\148c\251\133\136\228\201c\251\007\157\228\250D\173\001\248\001\248\001\248\001\248\198\248\001\248\177\136\177\136\177\136P\128P\128\196\234D\173\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalR\202\000\128\000\128R\202alalalalalalalalalalJ\169\000\128J\169alalalalalalalalalR\202\000\128\000\128R\202alalalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128R\202alalalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalalR\202\000\128\000\128\000\128\000\128R\202alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alal\000\128\000\128R\202\000\128\000\128J\169alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128R\202\000\128\000\128J\169alalal\000\128\000\128alalR\202\000\128\000\128\000\128\000\128\000\128R\202alalalalalalalalal\000\128alalalalalalalalalR\202\000\128\000\128\000\128\000\128\000\128R\202alal\000\128\000\128alalalR\202\000\128\000\128R\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalalalR\202\000\128\000\128R\202\000\128\000\128alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[2][13].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\000\128\000\128alalalR\202\000\128alalalalalalalalJ\169\000\128J\169alalalalalalalal\000\128\000\128alalalR\202\000\128alal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalal\000\128\000\128alalR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128alR\202\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128alalalalal\000\128\000\128alal\000\128\000\128R\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128R\202\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128alR\202\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128alalR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalal\000\128\000\128alal\000\128")
cards[2][13].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalal\240\201\197\189c\251c\251c\251c\251\228\201c\251E\206c\251\229\251C\208\001\248\196\234c\251c\251E\206\228\250d\222c\251c\251\229\251D\205v\202al1\198\000\1281\198alal\000\128al\000\128\000\128al\000\128alalalalC\188\165\236E\206c\251E\206c\251\196\234d\222\196\234\228\237\001\248\165\200\165\236E\206d\222c\251c\251\196\234l\251\196\234C\208C\188alal\000\128\000\128\000\128alal\000\128al\000\128\000\128al\000\128alalalalW\190C\188\001\248E\206E\206\228\213\197\189d\222E\206\197\216C\208\198\248C\208\228\213\196\234E\206\197\189d\222E\206\001\248C\188\218\206alal\023\223\000\128\023\223alal\000\128al\000\128\000\128al\000\128alalalalalC\208C\208D\205\228\201E\206E\206\197\189\197\189C\188C\188\197\216C\188D\205\165\172\197\189J\173d\222\197\189\001\248C\188alal\000\128\000\128\000\128\000\128\000\128al\000\128al\000\128\000\128al\000\128alalalalal\248\218C\208C\188\007\157D\168D\168C\188D\168C\148\198\148C\132C\132C\132C\132C\132\133\136C\132C\132C\132v\202alal\000\128\000\128\000\128\000\128\000\128al\000\128al\000\128\000\128al\000\128alalalalalalC\148C\132\007\157\240\201N\202v\202\218\206s\218s\218N\202N\202\203\185J\173\007\157J\173\007\157J\173\007\157alalalalal\000\128alald\222\000\128al\000\128\000\128al\000\128alalalalalal\244\177\248\218\157\239alalalalalalalal\157\239\248\218\157\239}\223}\223}\223\248\218alalalal\000\128\000\128\000\128al\228\250\000\128al\000\128\000\128al\000\128alalalalalal\244\177\222\223al\157\239\218\206alW\190v\202W\190W\190\222\223al\248\218\218\206\157\239}\223\218\206\157\239}\223alalalalalalal\228\250\000\128al\000\128\000\128al\000\128alalalalalal\208\148\157\239r\169v\202\218\206al\157\239}\223}\223al\248\218al}\223\157\239\218\206\157\239}\223}\223\248\218alalalalalal\157\239\228\250\000\128al\000\128\000\128al\000\128alalalalalal3\157v\202W\190W\190\248\218al\157\239\177\136\150\161\218\206alalalv\202\157\239\218\206\157\239\218\206}\223alalalalalal\157\239\228\250\000\128al\000\128\000\128al\000\128alalalalalalr\169\244\177\208\148\244\177v\202alW\190r\169\244\177\150\161alalal\218\206}\223\248\218}\223\248\218W\190alalalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalalW\190\150\161\248\218}\223\222\223\157\239alal\157\239}\223alalalal\218\206\218\206\218\206\218\206}\223W\190alalalalalal}\223c\251\000\128al\000\128\000\128al\000\128alalalalalv\2023\157alal\218\206alalalalalalalalal\248\218v\202\157\239\218\206\157\239v\202alalalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalal\157\239}\223\150\161\218\206alv\202\157\239\150\161W\190\248\218al}\223alal}\223\248\218\218\206}\223\248\218}\223\248\218\222\223alalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalv\202\218\206r\169}\223\157\239v\202\157\239al\244\177\150\161\157\239W\190alalv\202}\223}\223v\202}\223\218\206\248\218}\223alalalalal\157\239c\251\000\128al\000\128\000\128al\000\128alalalalal\218\206\248\218\244\177v\202\244\1773\157\208\148W\190\218\206\218\206\218\206al\157\239v\202\218\206\218\206}\223r\169\218\206v\202\244\177\218\206}\223alalal5\227l\251\000\128al\000\128\000\128al\000\128alalalalalalal\157\239alal\157\239\218\206alalalal}\223v\202W\190\218\206\248\218v\202\157\239}\223alalal\248\218\157\239alal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalalv\202}\223}\223alalalalalalal\218\206\218\206r\169\150\161W\190\248\218W\190\222\223\150\161v\202W\190W\190W\190\157\239alal}\223l\251\000\128al\000\128\000\128al\000\128alal1\198\000\1281\198al\244\177\218\206}\223\157\239\218\206\150\161\157\239}\223\248\218W\190\218\206\157\239\157\239\244\177\150\161\208\148C\188C\188\133\136C\148\177\1363\157alalal5\227l\251\000\128al\000\128\000\128al\000\128alal\000\128\000\128\000\128al\218\206\248\218\248\218W\190\133\136C\208\206\176\150\161\150\161\150\161\150\161W\190\177\136D\168\001\248\001\248C\188\133\136C\148\001\248\001\248\001\248\206\176}\223al\157\239l\251\000\128al\000\128\000\128al\000\128alal\023\223\000\128\023\223alal\177\1363\157\244\177C\132C\132C\148C\208\165\236C\208\001\248\001\248\001\248\001\248C\188\133\136C\132\177\136\001\248\165\200C\208\133\136\001\248C\208\218\206\218\206\243\251\000\128al\000\128\000\128al\000\128al\000\128\000\128\000\128\000\128\000\128alC\148j\161alP\128P\128\198\148C\132C\148C\208\001\248\001\248C\188\133\136C\132\007\157J\173\165\236C\208C\208\133\136\133\136C\208\228\250\228\201C\132\243\251\000\128al\000\128\000\128al\000\128al\000\128\000\128\000\128\000\128\000\128al\203\185C\132alD\173\229\251N\202P\128\133\136C\132C\148\133\136C\132J\173J\173d\222D\205\001\248C\208\001\248\133\136C\188D\205\228\250C\132\198\148\243\251\000\128al\000\128\000\128al\000\128v\202alal\000\128alalN\202C\132C\132v\202\204\226d\222\228\213\228\250l\251P\128\133\136\198\148P\128\196\234\196\234E\206\001\248C\208\001\248\198\248\001\248\001\248c\251\133\136\203\185C\132\243\251\000\128al\000\128\000\128al\000\128N\202al\000\128\000\128\000\128alC\132J\173\007\157\198\148alD\173\196\234f\250E\206\228\213l\251\196\234\228\213\228\213\228\250\197\216C\208\165\236\001\248\001\248\001\248D\205d\222J\173r\169\198\148\243\251\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\000\128\000\128alalalR\202\000\128alalalalalalalalJ\169\000\128J\169alalalalalalalal\000\128\000\128alalalR\202\000\128alal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128alalalalalalalJ\169\000\128\000\128\000\128J\169alalalalalalal\000\128\000\128alalR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128alalalalalalalal\023\223\000\128\000\128\000\128\023\223alalalalalalal\000\128\000\128alR\202\000\128\000\128alalal\000\128\000\128alal\000\128\000\128\000\128\000\128\000\128alalalalalalalalalal1\198\000\1281\198alalalalalalalal\000\128\000\128\000\128\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128\000\128\000\128alalalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128\000\128\000\128alalalalal\000\128\000\128alal\000\128\000\128R\202\000\128\000\128alalalalalalalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalalalalal\000\128\000\128R\202\000\128\000\128alalalal\000\128\000\128alal\000\128\000\128alR\202\000\128\000\128alalalalalalal1\198\000\128\023\223\000\128\023\223\000\1281\198alalalalalal\000\128\000\128alR\202\000\128\000\128alalal\000\128\000\128alal\000\128\000\128alalR\202\000\128\000\128alalalalalalalalal\000\128alalalalalalalalal\000\128\000\128alalR\202\000\128\000\128alal\000\128\000\128alal\000\128\000\128alalal\000\128\000\128alalalalalalalal\000\128\000\128\000\128alalalalalalalal\000\128\000\128alalal\000\128\000\128alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][1].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalal\165\232alalalalalalalalalalalalalalalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalalalalalalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalal\165\232\165\232\165\232alalalalalalalalalalalalalalalalalalalalalalal\165\232\165\232\165\232alalalal\000\128\000\128alalalQ\246\165\232\205\241\165\232Q\246alalalalalalalalalalalalalalalalalalalalalQ\246\165\232\205\241\165\232Q\246alalal\000\128\000\128alalal\165\232\165\232al\165\232\165\232alalalalalalalalalalalalalalalalalalalalal\165\232\165\232al\165\232\165\232alalal\000\128\000\128alalQ\246\165\232\165\232\165\232\165\232\165\232\148\250alalalalalalalalalalalalalalalalalalalQ\246\165\232\165\232\165\232\165\232\165\232\148\250alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232Q\246alQ\246\165\232\165\232alalalalalalalalalalalalalalalalalalal\165\232\165\232Q\246alQ\246\165\232\165\232alal\000\128\000\128alal\165\232\205\241alalal\205\241\165\232alalalalalalalalalalalalalalalalalalal\165\232\205\241alalal\205\241\165\232alal\000\128")
cards[3][1].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\156\251\165\232\165\232alalal\165\232\165\232\156\251alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\165\232\165\232\165\232\015\246al\015\246\165\232\165\232\165\232alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\165\232\165\232\165\232\165\232\015\246\165\232\165\232\165\232\165\232alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\156\251\165\232\156\251alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalalalalalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalalalalalalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalal\165\232\165\232\165\232alalalalalalalalalalalalalalalalalalalalalalal\165\232\165\232\165\232alalalal\000\128\000\128alalalQ\246\165\232\205\241\165\232Q\246alalalalalalalalalalalalalalalalalalalalalQ\246\165\232\205\241\165\232Q\246alalal\000\128\000\128alalal\165\232\165\232al\165\232\165\232alalalalalalalalalalalalalalalalalalalalal\165\232\165\232al\165\232\165\232alalal\000\128\000\128alalQ\246\165\232\165\232\165\232\165\232\165\232\148\250alalalalalalalalalalalalalalalalalalalQ\246\165\232\165\232\165\232\165\232\165\232\148\250alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232Q\246alQ\246\165\232\165\232alalalalalalalalalalalalalalalalalalal\165\232\165\232Q\246alQ\246\165\232\165\232alal\000\128\000\128alal\165\232\205\241alalal\205\241\165\232alalalalalalalalalalalalalalalalalalal\165\232\205\241alalal\205\241\165\232alal\000\128\156\243\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\156\247\222\255\189\247\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128{\243al")
cards[3][2].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalalalalalQ\242\164\228\164\228alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalalalalQ\242\164\228\164\228alal\000\128\000\128alalalalalQ\242\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalalalQ\242\164\228\164\228alalal\000\128\000\128alalalalQ\242\164\228\164\228alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalalQ\242\164\228\164\228alalalal\000\128\000\128alalalQ\242\164\228\164\228alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalQ\242\164\228\164\228alalalalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\155\251alalalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128")
cards[3][2].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalalalalalQ\242\164\228\164\228alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalalalalQ\242\164\228\164\228alal\000\128\000\128alalalalalQ\242\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalalalQ\242\164\228\164\228alalal\000\128\000\128alalalalQ\242\164\228\164\228alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalalQ\242\164\228\164\228alalalal\000\128\000\128alalalQ\242\164\228\164\228alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalQ\242\164\228\164\228alalalalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\155\251alalalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][3].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalalalal\246\246\205\241\164\228\164\228alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalalal\246\246\205\241\164\228\164\228alal\000\128\000\128alalalal\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\164\228\164\228\164\228\164\228alalal\000\128\000\128alalalalal\246\246\205\241\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalalal\246\246\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\155\251alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128")
cards[3][3].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\015\242alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\155\251alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalalalal\246\246\205\241\164\228\164\228alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalalal\246\246\205\241\164\228\164\228alal\000\128\000\128alalalal\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\164\228\164\228\164\228\164\228alalal\000\128\000\128alalalalal\246\246\205\241\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalalal\246\246\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\155\251alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][4].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalalalQ\242\164\228alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalalalalQ\242\164\228alalal\000\128\000\128alalalalalQ\242\164\228\164\228alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalalalQ\242\164\228\164\228alalal\000\128\000\128alalalalQ\242\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalQ\242\164\228\164\228\164\228alalal\000\128\000\128alalalQ\242\164\228\164\228\164\228\164\228alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalQ\242\164\228\164\228\164\228\164\228alalal\000\128\000\128alalQ\242\164\228\164\228al\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalQ\242\164\228\164\228al\164\228\164\228alalal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alalalalalal\164\228\164\228alalalalalalalalalal\015\242alalalalalalalalalalalalal\164\228\164\228alalal\000\128\000\128alalalalalal\164\228\164\228alalalalalalalalalal\155\251alalalalalalalalalalalalal\164\228\164\228alalal\000\128")
cards[3][4].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalal\000\128\000\128alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\015\242alalalalalalalalalalalalal\015\242alalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalQ\242\164\228alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalalalalQ\242\164\228alalal\000\128\000\128alalalalalQ\242\164\228\164\228alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalalalQ\242\164\228\164\228alalal\000\128\000\128alalalalQ\242\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalQ\242\164\228\164\228\164\228alalal\000\128\000\128alalalQ\242\164\228\164\228\164\228\164\228alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalQ\242\164\228\164\228\164\228\164\228alalal\000\128\000\128alalQ\242\164\228\164\228al\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalQ\242\164\228\164\228al\164\228\164\228alalal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alalalalalal\164\228\164\228alalalalalalalalalal\015\242alalalalalalalalalalalalal\164\228\164\228alalal\000\128\000\128alalalalalal\164\228\164\228alalalalalalalalalal\155\251alalalalalalalalalalalalal\164\228\164\228alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][5].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alalalalalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\165\232\165\232alalalalalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\165\232\165\232\165\232\165\232\205\241alalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalal\165\232\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alalalalalal\165\232\165\232alalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalalalal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalal\246\246\164\228\246\246alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alalal\165\232\165\232\165\232\165\232alalalalalalalalalalal\015\242alalalalalalalalalal\165\232\165\232\165\232\165\232alalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\155\251alalalalalalalalalalalalalalalalalal\000\128")
cards[3][5].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\164\228\015\242al\015\242\164\228alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalal\164\228\015\242al\015\242\164\228alalal\000\128\000\128alal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alal\000\128\000\128alalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalal\000\128\000\128alalal\246\246\164\228\164\228\164\228\246\246alalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalal\246\246\164\228\164\228\164\228\246\246alalal\000\128\000\128alalalal\246\246\164\228\246\246alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\246\246\164\228\246\246alalalal\000\128\000\128alalalalal\015\242alalalalalalalalalalalal\015\242alalalalalalalalalalalal\015\242alalalalal\000\128\000\128alalalalal\155\251alalalalalalalalalalalal\155\251alalalalalalalalalalalal\155\251alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alalalalalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\165\232\165\232alalalalalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\165\232\165\232\165\232\165\232\205\241alalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalal\165\232\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alalalalalal\165\232\165\232alalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalalalal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalal\246\246\164\228\246\246alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alalal\165\232\165\232\165\232\165\232alalalalalalalalalalal\015\242alalalalalalalalalal\165\232\165\232\165\232\165\232alalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\155\251alalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][6].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalQ\242\164\228\164\228\164\228\205\241alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228\205\241alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228alalalal\246\246alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228alalalal\246\246alal\000\128\000\128alal\164\228\164\228\205\241\164\228\164\228\246\246alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\164\228\164\228\205\241\164\228\164\228\246\246alalal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\205\241\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228alal\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228Q\242al\246\246\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228Q\242al\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\155\251alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128")
cards[3][6].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalal\000\128\000\128alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\015\242alalalalalalalalalalalalal\015\242alalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalal\000\128\000\128alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\015\242alalalalalalalalalalalalal\015\242alalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalQ\242\164\228\164\228\164\228\205\241alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228\205\241alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228alalalal\246\246alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228alalalal\246\246alal\000\128\000\128alal\164\228\164\228\205\241\164\228\164\228\246\246alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\164\228\164\228\205\241\164\228\164\228\246\246alalal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\205\241\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228alal\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228Q\242al\246\246\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228Q\242al\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\155\251alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][7].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalal\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalal\165\232\165\232\205\241alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalalal\165\232\165\232\205\241alalal\000\128\000\128alalalal\165\232\165\232alalalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalalal\165\232\165\232alalalal\000\128\000\128alalal\165\232\165\232\205\241alalalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\165\232\165\232\205\241alalalal\000\128\000\128alalal\165\232\165\232alalalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\165\232\165\232alalalalal\000\128\000\128alalal\165\232\165\232alalalalalalalalalalalalal\015\242alalalalalalalalalalal\165\232\165\232alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\155\251alalalalalalalalalalalalalalalalalal\000\128")
cards[3][7].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalal\000\128\000\128alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\015\242alalalalalalalalalalalalal\015\242alalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\015\242alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\155\251alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalal\000\128\000\128alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\015\242alalalalalalalalalalalalal\015\242alalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\155\251alalalalalalalalalalalalal\155\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalal\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalal\165\232\165\232\205\241alalalalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalalalalal\165\232\165\232\205\241alalal\000\128\000\128alalalal\165\232\165\232alalalalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalalalal\165\232\165\232alalalal\000\128\000\128alalal\165\232\165\232\205\241alalalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\165\232\165\232\205\241alalalal\000\128\000\128alalal\165\232\165\232alalalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\165\232\165\232alalalalal\000\128\000\128alalal\165\232\165\232alalalalalalalalalalalalal\015\242alalalalalalalalalalal\165\232\165\232alalalalal\000\128al\000\128alalalalalalalalalalalalalalalalal\155\251alalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][8].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228\246\246al\246\246\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\246\246al\246\246\164\228\164\228alal\000\128\000\128alal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alal\000\128\000\128alalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalal\000\128\000\128alal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228\246\246al\246\246\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228\246\246al\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\155\251alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128")
cards[3][8].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\164\228\015\242al\015\242\164\228alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalal\164\228\015\242al\015\242\164\228alalal\000\128\000\128alal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alal\000\128\000\128alalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalal\000\128\000\128alalal\246\246\164\228\164\228\164\228\246\246alalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalal\246\246\164\228\164\228\164\228\246\246alalal\000\128\000\128alalalal\246\246\164\228\246\246alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\246\246\164\228\246\246alalalal\000\128\000\128alalalalal\015\242alalalalalalalalalalalal\015\242alalalalalalalalalalalal\015\242alalalalal\000\128\000\128alalalalal\155\251alalalalalalalalalalalal\155\251alalalalalalalalalalalal\155\251alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\164\228\015\242al\015\242\164\228alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalal\164\228\015\242al\015\242\164\228alalal\000\128\000\128alal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alal\000\128\000\128alalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalal\000\128\000\128alalal\246\246\164\228\164\228\164\228\246\246alalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalal\246\246\164\228\164\228\164\228\246\246alalal\000\128\000\128alalalal\246\246\164\228\246\246alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\246\246\164\228\246\246alalalal\000\128\000\128alalalalal\015\242alalalalalalalalalalalal\015\242alalalalalalalalalalalal\015\242alalalalal\000\128\000\128alalalalal\155\251alalalalalalalalalalalal\155\251alalalalalalalalalalalal\155\251alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228\246\246al\246\246\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\246\246al\246\246\164\228\164\228alal\000\128\000\128alal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alal\000\128\000\128alalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalal\000\128\000\128alal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228\246\246al\246\246\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228\246\246al\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\155\251alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][9].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalal\205\241\165\232\165\232\165\232alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\205\241\165\232\165\232\165\232alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\205\241\165\232\165\232alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalal\165\232\165\232\205\241\165\232\165\232alal\000\128\000\128alalalalalal\165\232\165\232alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalalalalal\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalal\156\251\165\232\156\251alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\165\232\165\232alalalalalalalalalalal\148\250alalalalalalalalalalal\165\232\165\232\165\232\165\232alalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[3][9].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\000\128\000\128alalalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalalal\000\128\000\128alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalal\000\128\000\128alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalal\000\128\000\128alalalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalal\000\128\000\128alalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalal\000\128\000\128alalalalalalalalalal\156\251\165\232\156\251alalalalalalalalalalal\156\251\165\232\156\251alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\148\250alalalalalalalalalalalalal\148\250alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\165\232\015\246al\015\246\165\232alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\165\232\015\246al\015\246\165\232alal\000\128\000\128al\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232al\000\128\000\128al\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232al\000\128\000\128al\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232al\000\128\000\128al\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251al\000\128\000\128alal\156\251\165\232\165\232\165\232\156\251alalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalal\156\251\165\232\165\232\165\232\156\251alal\000\128\000\128alalal\156\251\165\232\156\251alalalalalalalalalalal\156\251\165\232\156\251alalalalalalalalalalal\156\251\165\232\156\251alalal\000\128\000\128alalalal\148\250alalalalalalalalalalalalal\148\250alalalalalalalalalalalalal\148\250alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\000\128\000\128alalalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalalal\000\128\000\128alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalal\000\128\000\128alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalal\000\128\000\128alalalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalal\000\128\000\128alalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalal\000\128\000\128alalalalalalalalalal\156\251\165\232\156\251alalalalalalalalalalal\156\251\165\232\156\251alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\148\250alalalalalalalalalalalalal\148\250alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\205\241\165\232\165\232\165\232alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\205\241\165\232\165\232\165\232alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\205\241\165\232\165\232alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalal\165\232\165\232\205\241\165\232\165\232alal\000\128\000\128alalalalalal\165\232\165\232alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalalalalal\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalal\156\251\165\232\156\251alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\165\232\165\232alalalalalalalalalalal\148\250alalalalalalalalalalal\165\232\165\232\165\232\165\232alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][10].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000al\252\251\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\252\251alal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\205\241alal\165\232\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalal\205\241alal\165\232\165\232alalal\000\128\000\128alal\205\241\165\232al\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalal\205\241\165\232al\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\205\241\205\241\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232al\165\232\205\241\205\241\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\247\246al\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232al\165\232\247\246al\165\232alal\000\128\000\128alal\165\232\165\232al\165\232al\247\246\165\232alalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalal\165\232\165\232al\165\232al\247\246\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\205\241\205\241\165\232alalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalal\165\232\165\232al\165\232\205\241\205\241\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\165\232\165\232\165\232alalalalalalalal\156\251\165\232\156\251alalalalalalalal\165\232\165\232al\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\148\250alalalalalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128")
cards[3][10].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\165\232\015\246al\015\246\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alal\000\128\000\128alalal\156\251\165\232\165\232\165\232\156\251alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalal\000\128\000\128alalalal\156\251\165\232\156\251alalalalalalalalalal\156\251\165\232\156\251alalalalalalalalalal\156\251\165\232\156\251alalalal\000\128\000\128alalalalal\148\250alalalalalalalalalalalal\148\250alalalalalalalalalalalal\148\250alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalalal\000\128\000\128alalalalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalalalal\000\128\000\128alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalal\000\128\000\128alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalal\000\128\000\128alalalalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalalal\000\128\000\128alalalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\156\251\165\232\156\251alalalalalalalalal\156\251\165\232\156\251alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalal\148\250alalalalalalalalalalal\148\250alalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\165\232\015\246al\015\246\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alal\000\128\000\128alalal\156\251\165\232\165\232\165\232\156\251alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalal\000\128\000\128alalalal\156\251\165\232\156\251alalalalalalalalalal\156\251\165\232\156\251alalalalalalalalalal\156\251\165\232\156\251alalalal\000\128\000\128alalalalal\148\250alalalalalalalalalalalal\148\250alalalalalalalalalalalal\148\250alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\205\241alal\165\232\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalal\205\241alal\165\232\165\232alalalal\000\128\000\128alal\205\241\165\232al\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalal\205\241\165\232al\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\205\241\205\241\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalal\165\232\165\232al\165\232\205\241\205\241\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\247\246al\165\232alalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalal\165\232\165\232al\165\232\247\246al\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232al\247\246\165\232alalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalal\165\232\165\232al\165\232al\247\246\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\205\241\205\241\165\232alalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalal\165\232\165\232al\165\232\205\241\205\241\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232\165\232\165\232alalalalalalalal\156\251\165\232\156\251alalalalalalal\165\232\165\232al\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\148\250alalalalalalalal\165\232\165\232alal\165\232\165\232alalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][11].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalal\165\232\165\232\165\232\165\232\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalalal\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232alalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalal\165\232\165\232al\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalalalal\156\251\165\232\156\251alalalalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alalal\165\232\165\232\205\241alalalalalalalalalalalal\148\250alalalalalalalalalalal\165\232\165\232\205\241alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[3][11].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128al}\223C\208C\208\133\136\001\248\198\248\001\248\001\248\198\248C\132\197\216C\148\165\236\001\248\001\248\198\248C\208\198\148C\208\133\136\001\248\198\248\001\248C\188C\188al\231\232\015\246al\015\246\165\232al\000\128al\000\128\000\128al\000\128alalW\190\001\248C\188\198\148C\208\165\172C\148\133\136\133\136C\208\165\172C\148\198\148D\168\198\148C\148\165\236D\168\133\136\133\136\133\136\133\136\001\248\228\201\165\232\165\232\165\232\015\246\165\232\165\232\165\232\000\128al\000\128\000\128al\000\128alalal\007\157\001\248C\208\165\172\001\248\165\236\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\198\248\001\248\001\248\001\248C\208\197\216\197\189\165\232\165\232\165\232\165\232\165\232\165\232\165\232\000\128al\000\128\000\128al\000\128alalalalD\168\001\248\001\248C\208C\188D\168\198\148C\148\133\136C\132\133\136\133\136\133\136\133\136C\132\133\136C\148\165\172D\168\165\200\203\185d\222\165\232\165\232\165\232\165\232\165\232\165\232\165\232\000\128al\000\128\000\128al\000\128alalalal\157\239C\132C\132C\132C\132C\132C\132C\132\133\136\198\148\133\136C\132\133\136C\132C\132C\132C\132C\132C\132C\132ald\222\189\251\165\232\165\232\165\232\165\232\165\232\189\251\000\128al\000\128\000\128al\000\128alalalal\157\239D\173\228\201d\222E\206d\222E\206\204\226alalalalalalalalalal\218\206k\218al\244\177\020\235\189\251\165\232\165\232\165\232\156\251\202\189\000\128al\000\128\000\128al\000\128alalalalW\190\228\201d\222E\206E\206E\206d\2225\227al\157\239v\202v\202\157\239alalal\248\218al}\223N\202alal\255\251al\156\251\165\232\156\251alf\177\000\128al\000\128\000\128al\000\128alalalalj\161E\206d\222E\206E\206E\206\228\201alv\202}\223alalW\190al}\223v\202al\157\239\150\161N\202alalalalal\148\250alal(\210\000\128al\000\128\000\128al\000\128alalalal\206\176E\206d\222E\206E\206E\206\228\201alalv\2023\1573\157\157\239al\218\206\244\177P\128\208\148\218\206d\222alalalalalalalD\205D\173\000\128al\000\128\000\128al\000\128alalalalD\173E\206E\206d\222d\222d\222\228\201al\218\206\244\177\150\161v\202\208\148alW\190W\190W\1903\157r\169k\218alalalalalalalD\173E\206\000\128al\000\128\000\128al\000\128alalal}\223D\173d\222d\222E\206\196\234d\222\228\201alal\218\206\244\1773\157alal\248\218al\244\177v\202s\218k\218alalalalalalal\197\189\228\201\000\128al\000\128\000\128al\000\128alalalW\190\228\201E\206d\222E\206\196\234E\206d\222\157\239alalalalalal\222\223\157\239alalk\218\196\234\218\206\157\239alalalal\157\239\228\201D\173\000\128al\000\128\000\128al\000\128alalW\190\228\213E\206\197\189d\222E\206\228\250E\206d\222\248\218alalal\218\206alalalv\202alal\203\185\228\201\228\201\197\189alalalalal\197\189\197\189\000\128al\000\128\000\128al\000\128alal\244\177\228\201d\222\196\234\228\201\228\201\228\250d\222d\222\204\226alalal\157\239v\202\248\218W\190alal\157\239\228\213}\223N\202\157\239alalalalal\228\201\007\157\000\128al\000\128\000\128al\000\128alalW\190\197\189\228\201\228\201d\222\196\234\197\189\228\250\228\2135\227alalalal\157\239\248\218W\190\157\239alW\190d\222al\218\2065\227alalalalalD\173\228\213\000\128al\000\128\000\128al\000\128v\202\007\157C\132\228\213D\173\197\189E\206\197\189\228\201D\173E\206\218\206alalal\218\206W\190v\202v\202v\202alD\173\228\201}\223d\222D\173alalalalal\197\189E\206\000\128al\000\128\000\128al\000\128C\132D\173d\222C\132k\218D\173\197\189D\173\228\250E\206\228\201\248\218alalalalal\248\218alalJ\173\228\201\228\201\240\201D\173\197\189alalal}\223\240\201D\173E\206\000\128al\000\128\000\128al\000\128C\132\197\189alalal\228\250\007\157\197\189\197\189D\173W\190r\169\244\177\157\239alalalal}\223C\132\228\201\228\201\197\189\007\157\228\201\203\185al\157\239W\190\157\239al\157\239C\132\000\128al\000\128\000\128al\000\128al\165\232\015\238\156\243\015\246\165\232\154\247\133\136\228\201d\222\240\201\150\161W\190\208\148r\169\218\206\218\206\244\177P\128\203\185r\169\198\148j\161\157\239alalalW\190alW\190P\128\218\206\208\148\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\015\246\165\232\165\232\165\232\228\201\196\234E\206\228\213c\251\240\201\228\250\228\201D\173\196\234W\1905\227\240\201j\161\157\239\228\213\007\157D\173N\202\244\177alal\177\136P\128r\169\218\206\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\165\232\165\232\165\232\165\232c\251c\251\007\157E\206\198\148\196\234C\132E\206\198\148\228\250W\190\240\201j\161\208\148\243\251v\202c\251\007\157d\222\228\201\157\239al\150\161P\128\208\148\218\206\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\165\232\165\232\165\232\165\232C\132d\222\197\189\133\136\228\250\196\234E\206\133\136\197\189k\218\240\201N\202W\190N\2025\227\196\234D\173\197\189\197\189\196\234\248\218al\208\148P\1283\157}\223\000\128al\000\128\000\128al\000\128\156\251\165\232\165\232\165\232\165\232\165\232\156\251\197\189C\132C\148\228\201c\251c\251c\251\197\189C\132\007\157\218\206N\202\203\185J\173\243\251\240\201\196\234\228\201D\173\196\234\204\226al\177\136\208\1483\157\218\206\000\128al\000\128\000\128al\000\128s\202\156\251\165\232\165\232\165\232\189\251\168\213\196\234d\222D\173C\132C\132\197\189C\132C\132C\188C\208\204\226N\202\208\148P\128\243\251\243\251k\218\228\201D\173\196\234E\206\157\239W\190\208\148P\128\244\177\000\128al\000\128\000\128al\000\128\027\227al\214\230\132\212\214\230alN\226\196\234\197\189d\222E\206D\173C\132C\148\001\248\001\248C\2085\227\240\201N\202j\161\243\251v\202d\222D\173\228\201\007\157C\132C\132C\132\240\201\228\201\133\136\000\128al\000\128\000\128al\000\128B\136!\132!\132!\132c\140B\136B\136\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\165\232\165\232\165\232\165\232\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalalal\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalalal\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232alalalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalal\165\232\165\232al\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalalalal\156\251\165\232\156\251alalalalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alalal\165\232\165\232\205\241alalalalalalalalalalalal\148\250alalalalalalalalalalal\165\232\165\232\205\241alalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][12].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalal\205\241\165\232\165\232\165\232alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalal\205\241\165\232\165\232\165\232alalalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\247\246\165\232\165\232Q\246alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalal\165\232\165\232\247\246\165\232\165\232Q\246alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalal\156\251\165\232\156\251alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alalal\165\232\165\232\165\232Q\246\165\232\165\232alalalalalalalalal\148\250alalalalalalalalalal\165\232\165\232\165\232Q\246\165\232\165\232alal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[3][12].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128B\136B\136\165\148\132\144!\132!\132\231\156\000\128al\000\128\000\128al\000\128alalalalalalalal\165\200W\190W\190W\190al\218\206v\202\218\206\218\2063\157I\233\133\136C\188\001\248\165\200C\208c\251c\251al\165\232\015\246al\015\246\165\232\217\255\008\161al\000\128\000\128al\000\128alalalalalalal\157\239\165\200W\190\244\177\157\239alalv\202W\190\218\206\150\161\150\161\197\216\133\136\165\236\001\248C\208\165\200D\173\165\232\165\232\165\232\015\246\165\232\165\232F\233\231\156al\000\128\000\128al\000\128alalalalalalals\218D\205W\190alalalalal}\223\244\177W\190\208\148I\233C\148\133\136\001\248\198\148C\208\001\248\165\232\165\232\165\232\165\232\165\232\165\232\139\237\231\156al\000\128\000\128al\000\128alalalalalalalL\209\197\189\222\223alalalal\218\206\248\218al}\223\177\136\244\177\001\248C\132C\188C\208D\168C\208\131\200\165\232\165\232\165\232\165\232\165\232\131\200\231\156al\000\128\000\128al\000\128alalalalalalalC\188k\218al\244\177}\223alW\190\157\239\157\239v\202al\218\2063\157L\209C\188\133\136\165\236D\168C\208c\144\165\232\165\232\165\232\165\232\165\232s\214\008\161al\000\128\000\128al\000\128alalalalalal}\223\197\216\203\185\208\1483\1573\157al}\223W\190W\190\157\239alal\177\136\150\161\198\248C\132\133\136\001\248D\168\148\210\181\222\165\232\165\232\165\232\156\251{\239\231\156al\000\128\000\128al\000\128alalalalalalL\209\228\237W\190P\128\244\177W\190alW\190P\128r\169\208\148}\223alr\169W\190L\209C\208C\132\165\200\001\248\016\218al\247\230\165\232\156\251alal\132\144al\000\128\000\128al\000\128alalalalalalC\208E\206W\190al\248\218\218\206alalv\202\244\177alalal\218\2063\157W\190\165\236C\148C\132\001\248s\218al{\239\148\250alalal!\132al\000\128\000\128al\000\128alalalalals\218C\208\197\189W\190al}\223alalalalalalalalal3\157\218\206W\190\001\248\133\136C\148C\208D\168C\208\165\172\165\200d\222al\000\128al\000\128\000\128al\000\128alalalalalC\208\228\237C\148W\190al\218\206alalalalalalalalal\244\177\244\177v\202L\209C\188C\132\197\216\001\248C\188D\205\229\251d\222\218\206\000\128al\000\128\000\128al\000\128alalalal\248\218\001\248d\222C\132\244\177al\218\206\157\239\218\206\244\177alalalalal\157\239\248\218\208\148\218\206W\190\198\248C\132C\132\001\248C\208C\208\228\201C\208)\249\000\128al\000\128\000\128al\000\128alalalalC\208\165\236\197\189C\132\133\136al\157\239\157\239alalalalalalal\157\239W\190\208\148W\190\218\206\208\213C\208\133\136C\148\198\248C\208C\208C\208C\188\000\128al\000\128\000\128al\000\128alalal\218\206\001\248\228\213\198\148\133\136C\132\157\239\248\218r\169\150\161\218\206alalalalal\244\177al\208\148\150\161\248\218\150\161\198\248C\148\133\136C\208C\208\244\177alal\000\128al\000\128\000\128al\000\128alalalC\208\001\248k\218\133\136C\148C\132\007\157al\248\218al\218\206\157\239alalalW\190\218\206\218\206\244\177\208\148W\190}\223\240\201\001\248C\132C\132\222\223alalal\000\128al\000\128\000\128al\000\128alal\240\201\001\248D\205D\173C\132C\148\133\136C\132\222\223\157\239\157\239alalalalW\190v\202\218\206\248\218\218\206P\128W\190\218\206W\190\198\248D\168C\132J\173alalal\000\128al\000\128\000\128al\000\128alalC\208\001\248\196\234C\132\133\136C\148C\132C\132\133\136alalal\248\218\218\206W\190\218\206v\202\218\206\218\206alP\128r\169\218\206\218\206W\190\001\248C\132C\132}\223alal\000\128al\000\128\000\128al\000\128alt\230l\249\238\229\205\222\206\177\141\185\198\148\133\136C\148C\132\133\136r\169\150\161\218\206\150\161W\190\244\177W\190W\190W\190\218\206P\128P\128W\190v\202W\190I\233C\208C\132\133\136alal\000\128al\000\128\000\128al\000\128al\165\232\015\246k\173\015\246\165\232s\255\230\250\228\250\228\250c\251\228\250\228\250\228\250\228\250\228\250\228\250\228\250\228\250c\251\228\250\228\250c\251f\2503\157v\202\218\206\244\177\001\248C\148C\132\203\185al\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\173\221\165\232\165\232(\213\016\194D\173D\173\198\148D\173\007\157\197\189\133\136\197\189\133\136\228\201C\132D\173D\173\198\148D\173\007\157\007\157W\190\218\206v\202L\209\001\248\133\136C\132al\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\165\232\165\232\165\232\231\232R\202\197\189\007\157D\173\007\157D\173\228\201\007\157d\222\198\148E\206J\173\197\189D\173D\173\197\189\007\157\198\148r\169\218\206\218\206\150\161\198\248D\168C\132\007\157\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\165\232\165\232\165\232\164\220\235\193D\173\197\189\197\189\228\201\228\201E\206\228\213E\206E\206\228\213d\222d\222d\222\196\234\228\250\196\234\196\234C\132W\190\218\206\218\206\206\176\001\248C\132\133\136\000\128al\000\128\000\128al\000\128\147\214\165\232\165\232\165\232\165\232\165\232\214\230\141\185C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132}\223}\223}\223\240\201\001\248D\168\000\128al\000\128\000\128al\000\1289\231\156\251\165\232\165\232\165\232\156\251\181\214K\221\228\201D\173E\206d\222\007\157D\173E\206C\132D\173\228\201\228\201D\173D\173C\188C\208C\188\165\200\165\200\165\200J\173al\248\218}\223C\188\001\248\000\128al\000\128\000\128al\000\128Z\243al\156\251\165\232\156\251al\181\254\017\222\228\201\197\189d\222\228\250D\173\228\250D\173\229\251\196\234d\222\007\157\229\251\165\172\001\248\198\248\001\248\001\248\001\248\001\248\177\1363\157al\222\223v\202\001\248\000\128al\000\128\000\128al\000\128\215\222al\140\177\008\173\140\177als\254\212\222\228\201j\161E\206\196\234\198\148c\251\133\136\228\201c\251\007\157\228\250D\173\001\248\001\248\001\248\001\248\198\248\001\248\177\136\177\136\177\136P\128P\128\196\234D\173\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\205\241\165\232\165\232\165\232alalalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalal\205\241\165\232\165\232\165\232alalalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\247\246\165\232\165\232Q\246alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalal\165\232\165\232\247\246\165\232\165\232Q\246alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalal\156\251\165\232\156\251alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alalal\165\232\165\232\165\232Q\246\165\232\165\232alalalalalalalalal\148\250alalalalalalalalalal\165\232\165\232\165\232Q\246\165\232\165\232alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[3][13].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalalalalalalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\165\232\205\241alalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalal\165\232\165\232al\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alal\165\232\165\232\165\232\205\241alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\205\241alalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232\205\241alalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalal\165\232\165\232al\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalal\156\251\165\232\156\251alalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alalalalalalalalalalalalalalalalalal\148\250alalalalalalalalalalalalalalalalalal\000\128")
cards[3][13].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalal\240\201\197\189c\251c\251c\251c\251\228\201c\251E\206c\251\229\251C\208\001\248\196\234c\251c\251E\206\228\250d\222c\251c\251\229\251D\205|\239\231\232\015\246al\015\246\165\232al\000\128al\000\128\000\128al\000\128alalalalC\188\165\236E\206c\251E\206c\251\196\234d\222\196\234\228\237\001\248\165\200\165\236E\206d\222c\251c\251\196\234l\251\196\234C\208C\188\231\232\197\232\165\232\015\246\165\232\165\232\165\232\000\128al\000\128\000\128al\000\128alalalalW\190C\188\001\248E\206E\206\228\213\197\189d\222E\206\197\216C\208\198\248C\208\228\213\196\234E\206\197\189d\222E\206\001\248C\188\218\206\165\232\165\232\165\232\165\232\165\232\165\232\165\232\000\128al\000\128\000\128al\000\128alalalalalC\208C\208D\205\228\201E\206E\206\197\189\197\189C\188C\188\197\216C\188D\205\165\172\197\189J\173d\222\197\189\001\248C\188al\165\232\165\232\165\232\165\232\165\232\165\232\165\232\000\128al\000\128\000\128al\000\128alalalalal\248\218C\208C\188\007\157D\168D\168C\188D\168C\148\198\148C\132C\132C\132C\132C\132\133\136C\132C\132C\132v\202al\156\251\165\232\165\232\165\232\165\232\165\232\189\251\000\128al\000\128\000\128al\000\128alalalalalalC\148C\132\007\157\240\201N\202v\202\218\206s\218s\218N\202N\202\203\185J\173\007\157J\173\007\157J\173\007\157alalal\156\251\165\232\165\232\165\232\188\251\015\235\000\128al\000\128\000\128al\000\128alalalalalal\244\177\248\218\157\239alalalalalalalal\157\239\248\218\157\239}\223}\223}\223\248\218alalalal\156\251\165\232\156\251alM\251\000\128al\000\128\000\128al\000\128alalalalalal\244\177\222\223al\157\239\218\206alW\190v\202W\190W\190\222\223al\248\218\218\206\157\239}\223\218\206\157\239}\223alalalal\148\250alal\007\251\000\128al\000\128\000\128al\000\128alalalalalal\208\148\157\239r\169v\202\218\206al\157\239}\223}\223al\248\218al}\223\157\239\218\206\157\239}\223}\223\248\218alalalalalal\157\239\228\250\000\128al\000\128\000\128al\000\128alalalalalal3\157v\202W\190W\190\248\218al\157\239\177\136\150\161\218\206alalalv\202\157\239\218\206\157\239\218\206}\223alalalalalal\157\239\228\250\000\128al\000\128\000\128al\000\128alalalalalalr\169\244\177\208\148\244\177v\202alW\190r\169\244\177\150\161alalal\218\206}\223\248\218}\223\248\218W\190alalalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalalW\190\150\161\248\218}\223\222\223\157\239alal\157\239}\223alalalal\218\206\218\206\218\206\218\206}\223W\190alalalalalal}\223c\251\000\128al\000\128\000\128al\000\128alalalalalv\2023\157alal\218\206alalalalalalalalal\248\218v\202\157\239\218\206\157\239v\202alalalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalal\157\239}\223\150\161\218\206alv\202\157\239\150\161W\190\248\218al}\223alal}\223\248\218\218\206}\223\248\218}\223\248\218\222\223alalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalv\202\218\206r\169}\223\157\239v\202\157\239al\244\177\150\161\157\239W\190alalv\202}\223}\223v\202}\223\218\206\248\218}\223alalalalal\157\239c\251\000\128al\000\128\000\128al\000\128alalalalal\218\206\248\218\244\177v\202\244\1773\157\208\148W\190\218\206\218\206\218\206al\157\239v\202\218\206\218\206}\223r\169\218\206v\202\244\177\218\206}\223alalal5\227l\251\000\128al\000\128\000\128al\000\128alalalalalalal\157\239alal\157\239\218\206alalalal}\223v\202W\190\218\206\248\218v\202\157\239}\223alalal\248\218\157\239alal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalalv\202}\223}\223alalalalalalal\218\206\218\206r\169\150\161W\190\248\218W\190\222\223\150\161v\202W\190W\190W\190\157\239alal}\223l\251\000\128al\000\128\000\128al\000\128al\165\232\015\246al\015\246\165\232\027\223\218\206}\223\157\239\218\206\150\161\157\239}\223\248\218W\190\218\206\157\239\157\239\244\177\150\161\208\148C\188C\188\133\136C\148\177\1363\157alalal5\227l\251\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\015\246\165\232\165\232\165\232\248\218\248\218W\190\133\136C\208\206\176\150\161\150\161\150\161\150\161W\190\177\136D\168\001\248\001\248C\188\133\136C\148\001\248\001\248\001\248\206\176}\223al\157\239l\251\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\165\232\165\232\165\232\165\232\177\1363\157\244\177C\132C\132C\148C\208\165\236C\208\001\248\001\248\001\248\001\248C\188\133\136C\132\177\136\001\248\165\200C\208\133\136\001\248C\208\218\206\218\206\243\251\000\128al\000\128\000\128al\000\128\165\232\165\232\165\232\165\232\165\232\165\232\165\232C\148j\161alP\128P\128\198\148C\132C\148C\208\001\248\001\248C\188\133\136C\132\007\157J\173\165\236C\208C\208\133\136\133\136C\208\228\250\228\201C\132\243\251\000\128al\000\128\000\128al\000\128\156\251\165\232\165\232\165\232\165\232\165\232\156\251\203\185C\132alD\173\229\251N\202P\128\133\136C\132C\148\133\136C\132J\173J\173d\222D\205\001\248C\208\001\248\133\136C\188D\205\228\250C\132\198\148\243\251\000\128al\000\128\000\128al\000\128al\156\251\165\232\165\232\165\232\188\251\178\218C\132C\132v\202\204\226d\222\228\213\228\250l\251P\128\133\136\198\148P\128\196\234\196\234E\206\001\248C\208\001\248\198\248\001\248\001\248c\251\133\136\203\185C\132\243\251\000\128al\000\128\000\128al\000\128y\239al\181\222\132\2049\239alJ\165J\173\007\157\198\148alD\173\196\234f\250E\206\228\213l\251\196\234\228\213\228\213\228\250\197\216C\208\165\236\001\248\001\248\001\248D\205d\222J\173r\169\198\148\243\251\000\128al\000\128\000\128al\000\128c\140\132\144B\136!\136!\132!\132B\136\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalal\165\232\015\246al\015\246\165\232alalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\165\232\205\241alalalalalalal\165\232\165\232\165\232\015\246\165\232\165\232\165\232alalalalalalal\165\232\165\232al\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alal\165\232\165\232\165\232\205\241alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\165\232\165\232\165\232\205\241alalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\156\251\165\232\165\232\165\232\165\232\165\232\156\251alalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232\205\241alalalalalalalal\156\251\165\232\165\232\165\232\156\251alalalalalalalal\165\232\165\232al\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalal\156\251\165\232\156\251alalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\148\250alalalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][1].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalal\165\232alalalalalalalalalalalalalalalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalalalalalalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalal\165\232\165\232\165\232alalalalalalalalalalalalalalalalalalalalalalal\165\232\165\232\165\232alalalal\000\128\000\128alalalQ\246\165\232\205\241\165\232Q\246alalalalalalalalalalalalalalalalalalalalalQ\246\165\232\205\241\165\232Q\246alalal\000\128\000\128alalal\165\232\165\232al\165\232\165\232alalalalalalalalalalalalalalalalalalalalal\165\232\165\232al\165\232\165\232alalal\000\128\000\128alalQ\246\165\232\165\232\165\232\165\232\165\232\148\250alalalalalalalalalalalalalalalalalalalQ\246\165\232\165\232\165\232\165\232\165\232\148\250alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232Q\246alQ\246\165\232\165\232alalalalalalalalalalalalalalalalalalal\165\232\165\232Q\246alQ\246\165\232\165\232alal\000\128\000\128alal\165\232\205\241alalal\205\241\165\232alalalalalalalalalalalalalalalalalalal\165\232\205\241alalal\205\241\165\232alal\000\128")
cards[4][1].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\165\232alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\165\232\165\232\165\232alal\156\251alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalal\165\232\165\232\165\232alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\165\232alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalalalalalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalalalalalalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalal\165\232\165\232\165\232alalalalalalalalalalalalalalalalalalalalalalal\165\232\165\232\165\232alalalal\000\128\000\128alalalQ\246\165\232\205\241\165\232Q\246alalalalalalalalalalalalalalalalalalalalalQ\246\165\232\205\241\165\232Q\246alalal\000\128\000\128alalal\165\232\165\232al\165\232\165\232alalalalalalalalalalalalalalalalalalalalal\165\232\165\232al\165\232\165\232alalal\000\128\000\128alalQ\246\165\232\165\232\165\232\165\232\165\232\148\250alalalalalalalalalalalalalalalalalalalQ\246\165\232\165\232\165\232\165\232\165\232\148\250alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232Q\246alQ\246\165\232\165\232alalalalalalalalalalalalalalalalalalal\165\232\165\232Q\246alQ\246\165\232\165\232alal\000\128\000\128alal\165\232\205\241alalal\205\241\165\232alalalalalalalalalalalalalalalalalalal\165\232\205\241alalal\205\241\165\232alal\000\128\156\243\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\156\247\222\255\189\247\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128{\243al")
cards[4][2].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\165\232alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalQ\246\165\232Q\246alalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalalalalalQ\242\164\228\164\228alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalQ\242\164\228\164\228alal\000\128\000\128alalalalalQ\242\164\228\164\228alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalQ\242\164\228\164\228alalal\000\128\000\128alalalalQ\242\164\228\164\228alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalQ\242\164\228\164\228alalalal\000\128\000\128alalalQ\242\164\228\164\228alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalQ\242\164\228\164\228alalalalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\165\232alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalalalalalalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128")
cards[4][2].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\165\232alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalQ\246\165\232Q\246alalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalalalalalQ\242\164\228\164\228alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalQ\242\164\228\164\228alal\000\128\000\128alalalalalQ\242\164\228\164\228alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalQ\242\164\228\164\228alalal\000\128\000\128alalalalQ\242\164\228\164\228alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalQ\242\164\228\164\228alalalal\000\128\000\128alalalQ\242\164\228\164\228alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalQ\242\164\228\164\228alalalalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalal\165\232alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalalalalalalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][3].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\165\232alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalQ\246\165\232Q\246alalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalalalal\246\246\205\241\164\228\164\228alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\246\246\205\241\164\228\164\228alal\000\128\000\128alalalal\164\228\164\228\164\228\164\228alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\164\228\164\228\164\228\164\228alalal\000\128\000\128alalalalal\246\246\205\241\164\228\164\228alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalal\246\246\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalalalalQ\246\165\232Q\246alalalalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\165\232alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalalalalalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128")
cards[4][3].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\165\232alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\165\232alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\165\232alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalQ\246\165\232Q\246alalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalalalal\246\246\205\241\164\228\164\228alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\246\246\205\241\164\228\164\228alal\000\128\000\128alalalal\164\228\164\228\164\228\164\228alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\164\228\164\228\164\228\164\228alalal\000\128\000\128alalalalal\246\246\205\241\164\228\164\228alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalal\246\246\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228alal\246\246\164\228\164\228alalalalalalalalQ\246\165\232Q\246alalalalalalalal\164\228\164\228alal\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\165\232alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalalalalalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][4].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalalalQ\242\164\228alalalalalalalalalal\165\232alalalalalalalalalalalalalQ\242\164\228alalal\000\128\000\128alalalalalQ\242\164\228\164\228alalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\242\164\228\164\228alalal\000\128\000\128alalalalQ\242\164\228\164\228\164\228alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalQ\242\164\228\164\228\164\228alalal\000\128\000\128alalalQ\242\164\228\164\228\164\228\164\228alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalQ\242\164\228\164\228\164\228\164\228alalal\000\128\000\128alalQ\242\164\228\164\228al\164\228\164\228alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalQ\242\164\228\164\228al\164\228\164\228alalal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalQ\246\165\232Q\246alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alalalalalal\164\228\164\228alalalalalalalalalal\165\232alalalalalalalalalalalalal\164\228\164\228alalal\000\128\000\128alalalalalal\164\228\164\228alalalalalalalalalalalalalalalalalalalalalalalal\164\228\164\228alalal\000\128")
cards[4][4].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalQ\242\164\228alalalalalalalalalal\165\232alalalalalalalalalalalalalQ\242\164\228alalal\000\128\000\128alalalalalQ\242\164\228\164\228alalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\242\164\228\164\228alalal\000\128\000\128alalalalQ\242\164\228\164\228\164\228alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalQ\242\164\228\164\228\164\228alalal\000\128\000\128alalalQ\242\164\228\164\228\164\228\164\228alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalQ\242\164\228\164\228\164\228\164\228alalal\000\128\000\128alalQ\242\164\228\164\228al\164\228\164\228alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalQ\242\164\228\164\228al\164\228\164\228alalal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalalQ\246\165\232Q\246alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alalalalalal\164\228\164\228alalalalalalalalalal\165\232alalalalalalalalalalalalal\164\228\164\228alalal\000\128\000\128alalalalalal\164\228\164\228alalalalalalalalalalalalalalalalalalalalalalalal\164\228\164\228alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][5].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alalalalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\165\232\165\232alalalalalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232\165\232\165\232\205\241alalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alalalalalal\165\232\165\232alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alalal\165\232\165\232\165\232\165\232alalalalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232\165\232\165\232alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[4][5].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alalalalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\165\232\165\232alalalalalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232\165\232\165\232\205\241alalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alalalalalal\165\232\165\232alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alalal\165\232\165\232\165\232\165\232alalalalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232\165\232\165\232alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][6].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalQ\242\164\228\164\228\164\228\205\241alalalalalalalalalal\164\228alalalalalalalalalalQ\242\164\228\164\228\164\228\205\241alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228alalalal\246\246alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228alalalal\246\246alal\000\128\000\128alal\164\228\164\228\205\241\164\228\164\228\246\246alalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalal\164\228\164\228\205\241\164\228\164\228\246\246alalal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\205\241\164\228\164\228alalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalal\164\228\164\228alal\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228Q\242al\246\246\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228Q\242al\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalal\246\246\164\228\246\246alalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\164\228alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128")
cards[4][6].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\164\228alalalalalalalalalalalalal\164\228alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\164\228alalalalalalalalalalalalal\164\228alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\164\228alalalalalalalalalalalalal\164\228alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalalalal\000\128\000\128alalalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\000\128\000\128alalalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalalalal\000\128\000\128alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalalalal\000\128\000\128alalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalalal\246\246\164\228\246\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\164\228alalalalalalalalalalalalal\164\228alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalQ\242\164\228\164\228\164\228\205\241alalalalalalalalalal\164\228alalalalalalalalalalQ\242\164\228\164\228\164\228\205\241alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228\164\228alal\000\128\000\128alal\164\228\164\228alalalal\246\246alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228alalalal\246\246alal\000\128\000\128alal\164\228\164\228\205\241\164\228\164\228\246\246alalalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalal\164\228\164\228\205\241\164\228\164\228\246\246alalal\000\128\000\128alal\164\228\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228alal\205\241\164\228\164\228alalalalalal\155\251\164\228\164\228\164\228\164\228\164\228\155\251alalalalalal\164\228\164\228alal\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228Q\242al\246\246\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228Q\242al\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalal\246\246\164\228\246\246alalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\164\228alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][7].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalalalal\165\232\165\232alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalal\165\232\165\232\205\241alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\165\232\165\232\205\241alalal\000\128\000\128alalalal\165\232\165\232alalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\165\232\165\232alalalal\000\128\000\128alalal\165\232\165\232\205\241alalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\165\232\165\232\205\241alalalal\000\128\000\128alalal\165\232\165\232alalalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\165\232\165\232alalalalal\000\128\000\128alalal\165\232\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\165\232\165\232alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[4][7].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\165\232alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalal\165\232alalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalalalal\165\232\165\232alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalal\165\232\165\232\205\241alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\165\232\165\232\205\241alalal\000\128\000\128alalalal\165\232\165\232alalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\165\232\165\232alalalal\000\128\000\128alalal\165\232\165\232\205\241alalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\165\232\165\232\205\241alalalal\000\128\000\128alalal\165\232\165\232alalalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\165\232\165\232alalalalal\000\128\000\128alalal\165\232\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\165\232\165\232alalalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][8].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228\246\246al\246\246\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\246\246al\246\246\164\228\164\228alal\000\128\000\128alal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alal\000\128\000\128alalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalal\000\128\000\128alal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228\246\246al\246\246\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228\246\246al\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\155\251alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128")
cards[4][8].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalal\164\228\015\242al\015\242\164\228alalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalal\164\228\164\228\164\228\015\242\164\228\164\228\164\228alalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alal\164\228\164\228\246\246al\246\246\164\228\164\228alalalalalal\164\228\164\228\164\228\164\228\164\228\164\228\164\228alalalalalal\164\228\164\228\246\246al\246\246\164\228\164\228alal\000\128\000\128alal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alalalalalal\015\242\164\228\164\228\164\228\164\228\164\228\015\242alalalalalal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alal\000\128\000\128alalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalalalalalalal\164\228\164\228\164\228\164\228\164\228alalal\000\128\000\128alal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alalalalalalal\246\246\164\228\164\228\164\228\246\246alalalalalalal\164\228\164\228\205\241\246\246\205\241\164\228\164\228alal\000\128\000\128alal\164\228\164\228\246\246al\246\246\164\228\164\228alalalalalalalal\246\246\164\228\246\246alalalalalalalal\164\228\164\228\246\246al\246\246\164\228\164\228alal\000\128\000\128alalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alalalalalalalalal\015\242alalalalalalalalalQ\242\164\228\164\228\164\228\164\228\164\228Q\242alal\000\128\000\128alalalQ\242\164\228\164\228\164\228Q\242alalalalalalalalalal\155\251alalalalalalalalalalQ\242\164\228\164\228\164\228Q\242alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][9].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalal\205\241\165\232\165\232\165\232alalalalalalalalalalal\165\232alalalalalalalalalalal\205\241\165\232\165\232\165\232alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\205\241\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\165\232\165\232\205\241\165\232\165\232alal\000\128\000\128alalalalalal\165\232\165\232alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalalal\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\165\232\165\232alalalalalalalalalalal\165\232alalalalalalalalalalal\165\232\165\232\165\232\165\232alalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[4][9].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalal\000\128\000\128alalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalal\000\128\000\128alal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alal\000\128\000\128al\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241al\000\128\000\128al\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241al\000\128\000\128alal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alal\000\128\000\128alalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalal\000\128\000\128alalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\000\128\000\128alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalal\000\128\000\128alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\000\128\000\128alalalalalalalalalalal\165\232alalalalalalalalalalalalal\165\232alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\205\241\165\232\165\232\165\232alalalalalalalalalalal\165\232alalalalalalalalalalal\205\241\165\232\165\232\165\232alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\205\241\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalal\165\232\165\232\205\241\165\232\165\232alal\000\128\000\128alalalalalal\165\232\165\232alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalalal\165\232\165\232alal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\165\232\165\232alalalalalalalalalalal\165\232alalalalalalalalalalal\165\232\165\232\165\232\165\232alalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][10].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000al\252\251\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\252\251alal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\205\241alal\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalal\205\241alal\165\232\165\232alalal\000\128\000\128alal\205\241\165\232al\165\232\165\232\165\232\165\232alalalalalalalalQ\246\165\232Q\246alalalalalalalal\205\241\165\232al\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\205\241\205\241\165\232alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\165\232\165\232al\165\232\205\241\205\241\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\247\246al\165\232alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232al\165\232\247\246al\165\232alal\000\128\000\128alal\165\232\165\232al\165\232al\247\246\165\232alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232al\165\232al\247\246\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\205\241\205\241\165\232alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\165\232\165\232al\165\232\205\241\205\241\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\165\232\165\232\165\232alalalalalalalalQ\246\165\232Q\246alalalalalalalal\165\232\165\232al\165\232\165\232\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128")
cards[4][10].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalal\165\232alalalalalalalalalalal\165\232alalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalal\000\128\000\128alalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalal\000\128\000\128alalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\000\128\000\128alalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\000\128\000\128alalalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalal\000\128\000\128alalalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalal\000\128\000\128alalalalalalalalalalalal\165\232alalalalalalalalalalal\165\232alalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alal\000\128\000\128alalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalal\000\128\000\128alalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalalalQ\246\165\232Q\246alalalal\000\128\000\128alalalalal\165\232alalalalalalalalalalalal\165\232alalalalalalalalalalalal\165\232alalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\205\241alal\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalal\205\241alal\165\232\165\232alalalal\000\128\000\128alal\205\241\165\232al\165\232\165\232\165\232\165\232alalalalalalalalQ\246\165\232Q\246alalalalalalal\205\241\165\232al\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\205\241\205\241\165\232alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalal\165\232\165\232al\165\232\205\241\205\241\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\247\246al\165\232alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalal\165\232\165\232al\165\232\247\246al\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232al\247\246\165\232alalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalal\165\232\165\232al\165\232al\247\246\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\205\241\205\241\165\232alalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalal\165\232\165\232al\165\232\205\241\205\241\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232\165\232\165\232alalalalalalalalQ\246\165\232Q\246alalalalalalal\165\232\165\232al\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\165\232alalalalalalalal\165\232\165\232alal\165\232\165\232alalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][11].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalal\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalalal\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalalalal\165\232\165\232alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\165\232\165\232al\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alalal\165\232\165\232\205\241alalalalalalalalalalalal\165\232alalalalalalalalalalal\165\232\165\232\205\241alalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[4][11].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128al}\223C\208C\208\133\136\001\248\198\248\001\248\001\248\198\248C\132\197\216C\148\165\236\001\248\001\248\198\248C\208\198\148C\208\133\136\001\248\198\248\001\248C\188C\188alalal\165\232alal\190\243\000\128al\000\128\000\128al\000\128alalW\190\001\248C\188\198\148C\208\165\172C\148\133\136\133\136C\208\165\172C\148\198\148D\168\198\148C\148\165\236D\168\133\136\133\136\133\136\133\136\001\248\228\201\171\218alQ\246\165\232Q\246al\214\234\000\128al\000\128\000\128al\000\128alalal\007\157\001\248C\208\165\172\001\248\165\236\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\001\248\198\248\001\248\001\248\001\248C\208\197\216\197\189al\181\250\165\232\165\232\165\232\148\250al\000\128al\000\128\000\128al\000\128alalalalD\168\001\248\001\248C\208C\188D\168\198\148C\148\133\136C\132\133\136\133\136\133\136\133\136C\132\133\136C\148\165\172D\168\165\200\203\185d\222\205\241\165\232\165\232\165\232\165\232\165\232\205\241\000\128al\000\128\000\128al\000\128alalalal\157\239C\132C\132C\132C\132C\132C\132C\132\133\136\198\148\133\136C\132\133\136C\132C\132C\132C\132C\132C\132C\132ald\222\205\241\165\232\165\232\165\232\165\232\165\232\205\241\000\128al\000\128\000\128al\000\128alalalal\157\239D\173\228\201d\222E\206d\222E\206\204\226alalalalalalalalalal\218\206k\218al\244\177x\243\148\250\165\232\165\232\165\232\181\250O\206\000\128al\000\128\000\128al\000\128alalalalW\190\228\201d\222E\206E\206E\206d\2225\227al\157\239v\202v\202\157\239alalal\248\218al}\223N\202alal\190\243alQ\246\165\232\016\234alE\173\000\128al\000\128\000\128al\000\128alalalalj\161E\206d\222E\206E\206E\206\228\201alv\202}\223alalW\190al}\223v\202al\157\239\150\161N\202alalalalal\165\232alal\242\230\000\128al\000\128\000\128al\000\128alalalal\206\176E\206d\222E\206E\206E\206\228\201alalv\2023\1573\157\157\239al\218\206\244\177P\128\208\148\218\206d\222alalalalalalalD\205D\173\000\128al\000\128\000\128al\000\128alalalalD\173E\206E\206d\222d\222d\222\228\201al\218\206\244\177\150\161v\202\208\148alW\190W\190W\1903\157r\169k\218alalalalalalalD\173E\206\000\128al\000\128\000\128al\000\128alalal}\223D\173d\222d\222E\206\196\234d\222\228\201alal\218\206\244\1773\157alal\248\218al\244\177v\202s\218k\218alalalalalalal\197\189\228\201\000\128al\000\128\000\128al\000\128alalalW\190\228\201E\206d\222E\206\196\234E\206d\222\157\239alalalalalal\222\223\157\239alalk\218\196\234\218\206\157\239alalalal\157\239\228\201D\173\000\128al\000\128\000\128al\000\128alalW\190\228\213E\206\197\189d\222E\206\228\250E\206d\222\248\218alalal\218\206alalalv\202alal\203\185\228\201\228\201\197\189alalalalal\197\189\197\189\000\128al\000\128\000\128al\000\128alal\244\177\228\201d\222\196\234\228\201\228\201\228\250d\222d\222\204\226alalal\157\239v\202\248\218W\190alal\157\239\228\213}\223N\202\157\239alalalalal\228\201\007\157\000\128al\000\128\000\128al\000\128alalW\190\197\189\228\201\228\201d\222\196\234\197\189\228\250\228\2135\227alalalal\157\239\248\218W\190\157\239alW\190d\222al\218\2065\227alalalalalD\173\228\213\000\128al\000\128\000\128al\000\128v\202\007\157C\132\228\213D\173\197\189E\206\197\189\228\201D\173E\206\218\206alalal\218\206W\190v\202v\202v\202alD\173\228\201}\223d\222D\173alalalalal\197\189E\206\000\128al\000\128\000\128al\000\128C\132D\173d\222C\132k\218D\173\197\189D\173\228\250E\206\228\201\248\218alalalalal\248\218alalJ\173\228\201\228\201\240\201D\173\197\189alalal}\223\240\201D\173E\206\000\128al\000\128\000\128al\000\128\214\214\209\218al\198\232alq\255\213\214\197\189\197\189D\173W\190r\169\244\177\157\239alalalal}\223C\132\228\201\228\201\197\189\007\157\228\201\203\185al\157\239W\190\157\239al\157\239C\132\000\128al\000\128\000\128al\000\128t\206al1\230\164\228Q\242al\241\234\133\136\228\201d\222\240\201\150\161W\190\208\148r\169\218\206\218\206\244\177P\128\203\185r\169\198\148j\161\157\239alalalW\190alW\190P\128\218\206\208\148\000\128al\000\128\000\128al\000\128\024\223\247\250\165\232\165\232\165\232\148\250R\202\228\201\196\234E\206\228\213c\251\240\201\228\250\228\201D\173\196\234W\1905\227\240\201j\161\157\239\228\213\007\157D\173N\202\244\177alal\177\136P\128r\169\218\206\000\128al\000\128\000\128al\000\128R\246\139\237\165\232\165\232\165\232\007\233\213\246c\251c\251\007\157E\206\198\148\196\234C\132E\206\198\148\228\250W\190\240\201j\161\208\148\243\251v\202c\251\007\157d\222\228\201\157\239al\150\161P\128\208\148\218\206\000\128al\000\128\000\128al\000\128\205\241\165\232\165\232\165\232\165\232\165\232\247\246C\132d\222\197\189\133\136\228\250\196\234E\206\133\136\197\189k\218\240\201N\202W\190N\2025\227\196\234D\173\197\189\197\189\196\234\248\218al\208\148P\1283\157}\223\000\128al\000\128\000\128al\000\128als\246\165\232\165\232\165\232s\246al\197\189C\132C\148\228\201c\251c\251c\251\197\189C\132\007\157\218\206N\202\203\185J\173\243\251\240\201\196\234\228\201D\173\196\234\204\226al\177\136\208\1483\157\218\206\000\128al\000\128\000\128al\000\128\174\177alQ\246\165\232Q\246al\212\234\196\234d\222D\173C\132C\132\197\189C\132C\132C\188C\208\204\226N\202\208\148P\128\243\251\243\251k\218\228\201D\173\196\234E\206\157\239W\190\208\148P\128\244\177\000\128al\000\128\000\128al\000\128\022\190alR\202\132\204\247\222al\212\234\196\234\197\189d\222E\206D\173C\132C\148\001\248\001\248C\2085\227\240\201N\202j\161\243\251v\202d\222D\173\228\201\007\157C\132C\132C\132\240\201\228\201\133\136\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\165\232\165\232\165\232\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalalal\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalal\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalalalal\165\232\165\232\165\232\165\232\165\232alal\000\128\000\128alalalalal\165\232\165\232alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alalalalal\165\232\165\232alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalalalalal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\165\232\165\232al\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alalal\165\232\165\232\205\241alalalalalalalalalalalal\165\232alalalalalalalalalalal\165\232\165\232\205\241alalalal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][12].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alalal\205\241\165\232\165\232\165\232alalalalalalalalalalal\165\232alalalalalalalalalal\205\241\165\232\165\232\165\232alalalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\247\246\165\232\165\232Q\246alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\165\232\165\232\247\246\165\232\165\232Q\246alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alalal\165\232\165\232\165\232Q\246\165\232\165\232alalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232\165\232Q\246\165\232\165\232alal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[4][12].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128B\136B\136\165\148\132\144!\132!\132\231\156\000\128al\000\128\000\128al\000\128alalalalalalalal\165\200W\190W\190W\190al\218\206v\202\218\206\218\2063\157I\233\133\136C\188\001\248\165\200C\208c\251c\251al\148\246al\165\232al\024\251\218\255\008\161al\000\128\000\128al\000\128alalalalalalal\157\239\165\200W\190\244\177\157\239alalv\202W\190\218\206\150\161\150\161\197\216\133\136\165\236\001\248C\208\165\200D\173alalQ\246\165\232Q\246j\237\170\237\231\156al\000\128\000\128al\000\128alalalalalalals\218D\205W\190alalalalal}\223\244\177W\190\208\148I\233C\148\133\136\001\248\198\148C\208\001\248al\148\250\165\232\165\232\165\232\173\241\189\255\231\156al\000\128\000\128al\000\128alalalalalalalL\209\197\189\222\223alalalal\218\206\248\218al}\223\177\136\244\177\001\248C\132C\188C\208D\168C\208\205\241\165\232\165\232\165\232\165\232\165\232\205\241\231\156al\000\128\000\128al\000\128alalalalalalalC\188k\218al\244\177}\223alW\190\157\239\157\239v\202al\218\2063\157L\209C\188\133\136\165\236D\168C\208I\201\165\232\165\232\165\232\165\232\165\232\205\241\008\161al\000\128\000\128al\000\128alalalalalal}\223\197\216\203\185\208\1483\1573\157al}\223W\190W\190\157\239alal\177\136\150\161\198\248C\132\133\136\001\248D\1689\231\180\238\165\232\165\232\165\232\024\251{\239\231\156al\000\128\000\128al\000\128alalalalalalL\209\228\237W\190P\128\244\177W\190alW\190P\128r\169\208\148}\223alr\169W\190L\209C\208C\132\165\200\001\2481\222alR\242\165\232Q\246alal\132\144al\000\128\000\128al\000\128alalalalalalC\208E\206W\190al\248\218\218\206alalv\202\244\177alalal\218\2063\157W\190\165\236C\148C\132\001\248\148\218al\189\247\165\232alalal!\132al\000\128\000\128al\000\128alalalalals\218C\208\197\189W\190al}\223alalalalalalalalal3\157\218\206W\190\001\248\133\136C\148C\208D\168C\208\165\172\165\200d\222al\000\128al\000\128\000\128al\000\128alalalalalC\208\228\237C\148W\190al\218\206alalalalalalalalal\244\177\244\177v\202L\209C\188C\132\197\216\001\248C\188D\205\229\251d\222\218\206\000\128al\000\128\000\128al\000\128alalalal\248\218\001\248d\222C\132\244\177al\218\206\157\239\218\206\244\177alalalalal\157\239\248\218\208\148\218\206W\190\198\248C\132C\132\001\248C\208C\208\228\201C\208)\249\000\128al\000\128\000\128al\000\128alalalalC\208\165\236\197\189C\132\133\136al\157\239\157\239alalalalalalal\157\239W\190\208\148W\190\218\206\208\213C\208\133\136C\148\198\248C\208C\208C\208C\188\000\128al\000\128\000\128al\000\128alalal\218\206\001\248\228\213\198\148\133\136C\132\157\239\248\218r\169\150\161\218\206alalalalal\244\177al\208\148\150\161\248\218\150\161\198\248C\148\133\136C\208C\208\244\177alal\000\128al\000\128\000\128al\000\128alalalC\208\001\248k\218\133\136C\148C\132\007\157al\248\218al\218\206\157\239alalalW\190\218\206\218\206\244\177\208\148W\190}\223\240\201\001\248C\132C\132\222\223alalal\000\128al\000\128\000\128al\000\128alal\240\201\001\248D\205D\173C\132C\148\133\136C\132\222\223\157\239\157\239alalalalW\190v\202\218\206\248\218\218\206P\128W\190\218\206W\190\198\248D\168C\132J\173alalal\000\128al\000\128\000\128al\000\128alalC\208\001\248\196\234C\132\133\136C\148C\132C\132\133\136alalal\248\218\218\206W\190\218\206v\202\218\206\218\206alP\128r\169\218\206\218\206W\190\001\248C\132C\132}\223alal\000\128al\000\128\000\128al\000\128alt\230l\249\238\229\205\222\206\177\141\185\198\148\133\136C\148C\132\133\136r\169\150\161\218\206\150\161W\190\244\177W\190W\190W\190\218\206P\128P\128W\190v\202W\190I\233C\208C\132\133\136alal\000\128al\000\128\000\128al\000\128al0\242\024\251\007\209\156\255R\242\183\255\230\250\228\250\228\250c\251\228\250\228\250\228\250\228\250\228\250\228\250\228\250\228\250c\251\228\250\228\250c\251f\2503\157v\202\218\206\244\177\001\248C\148C\132\203\185al\000\128al\000\128\000\128al\000\128al\189\255\016\242\197\232Q\246\206\241r\234\016\194D\173D\173\198\148D\173\007\157\197\189\133\136\197\189\133\136\228\201C\132D\173D\173\198\148D\173\007\157\007\157W\190\218\206v\202L\209\001\248\133\136C\132al\000\128al\000\128\000\128al\000\128al\148\250\165\232\165\232\165\232s\2509\251R\202\197\189\007\157D\173\007\157D\173\228\201\007\157d\222\198\148E\206J\173\197\189D\173D\173\197\189\007\157\198\148r\169\218\206\218\206\150\161\198\248D\168C\132\007\157\000\128al\000\128\000\128al\000\128\205\241\165\232\165\232\165\232\165\232\165\232\205\241\235\193D\173\197\189\197\189\228\201\228\201E\206\228\213E\206E\206\228\213d\222d\222d\222\196\234\228\250\196\234\196\234C\132W\190\218\206\218\206\206\176\001\248C\132\133\136\000\128al\000\128\000\128al\000\128\205\241\165\232\165\232\165\232\165\232\165\232\205\241\141\185C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132C\132}\223}\223}\223\240\201\001\248D\168\000\128al\000\128\000\128al\000\128al\148\250\165\232\165\232\165\232\181\250\156\243K\221\228\201D\173E\206d\222\007\157D\173E\206C\132D\173\228\201\228\201D\173D\173C\188C\208C\188\165\200\165\200\165\200J\173al\248\218}\223C\188\001\248\000\128al\000\128\000\128al\000\128{\247alQ\246\165\232Q\246al\247\254\017\222\228\201\197\189d\222\228\250D\173\228\250D\173\229\251\196\234d\222\007\157\229\251\165\172\001\248\198\248\001\248\001\248\001\248\001\248\177\1363\157al\222\223v\202\001\248\000\128al\000\128\000\128al\000\128\025\231alal\165\232s\206al\247\254\212\222\228\201j\161E\206\196\234\198\148c\251\133\136\228\201c\251\007\157\228\250D\173\001\248\001\248\001\248\001\248\198\248\001\248\177\136\177\136\177\136P\128P\128\196\234D\173\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalal\205\241\165\232\165\232\165\232alalalalalalalalalalal\165\232alalalalalalalalalal\205\241\165\232\165\232\165\232alalalal\000\128\000\128alal\205\241\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalal\165\232\165\232alal\165\232\165\232alalal\000\128\000\128alal\165\232\165\232\247\246\165\232\165\232Q\246alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalal\165\232\165\232\247\246\165\232\165\232Q\246alalal\000\128\000\128alal\165\232\165\232\165\232\165\232\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalal\165\232\165\232\165\232\165\232\165\232\165\232alalal\000\128\000\128alalal\165\232\165\232\165\232Q\246\165\232\165\232alalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232\165\232Q\246\165\232\165\232alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")
cards[4][13].top = image.new("\039\000\000\000\011\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000alal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alalal\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128al\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\165\232\205\241alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232al\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alal\165\232\165\232\165\232\205\241alalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\165\232\165\232\165\232\205\241alalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232\205\241alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\165\232\165\232al\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128")
cards[4][13].bottom = image.new("\039\000\000\000\040\000\000\000\000\000\000\000\078\000\000\000\016\000\001\000\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128al\000\128alalal\240\201\197\189c\251c\251c\251c\251\228\201c\251E\206c\251\229\251C\208\001\248\196\234c\251c\251E\206\228\250d\222c\251c\251\229\251D\205\216\210al{\239\165\232alalal\000\128al\000\128\000\128al\000\128alalalalC\188\165\236E\206c\251E\206c\251\196\234d\222\196\234\228\237\001\248\165\200\165\236E\206d\222c\251c\251\196\234l\251\196\234C\208C\188alalQ\246\165\232Q\246alal\000\128al\000\128\000\128al\000\128alalalalW\190C\188\001\248E\206E\206\228\213\197\189d\222E\206\197\216C\208\198\248C\208\228\213\196\234E\206\197\189d\222E\206\001\248C\188\218\206al\148\250\165\232\165\232\165\232\148\250al\000\128al\000\128\000\128al\000\128alalalalalC\208C\208D\205\228\201E\206E\206\197\189\197\189C\188C\188\197\216C\188D\205\165\172\197\189J\173d\222\197\189\001\248C\188al\205\241\165\232\165\232\165\232\165\232\165\232\205\241\000\128al\000\128\000\128al\000\128alalalalal\248\218C\208C\188\007\157D\168D\168C\188D\168C\148\198\148C\132C\132C\132C\132C\132\133\136C\132C\132C\132v\202al\205\241\165\232\165\232\165\232\165\232\165\232\205\241\000\128al\000\128\000\128al\000\128alalalalalalC\148C\132\007\157\240\201N\202v\202\218\206s\218s\218N\202N\202\203\185J\173\007\157J\173\007\157J\173\007\157alalal\148\250\165\232\165\232\165\232\148\250\016\239\000\128al\000\128\000\128al\000\128alalalalalal\244\177\248\218\157\239alalalalalalalal\157\239\248\218\157\239}\223}\223}\223\248\218alalalalQ\246\165\232Q\246al+\251\000\128al\000\128\000\128al\000\128alalalalalal\244\177\222\223al\157\239\218\206alW\190v\202W\190W\190\222\223al\248\218\218\206\157\239}\223\218\206\157\239}\223alalalal\165\232alalq\255\000\128al\000\128\000\128al\000\128alalalalalal\208\148\157\239r\169v\202\218\206al\157\239}\223}\223al\248\218al}\223\157\239\218\206\026\227\250\210}\223\248\218alalalalalal\157\239\228\250\000\128al\000\128\000\128al\000\128alalalalalal3\157v\202W\190W\190\248\218al\157\239\177\136\150\161\218\206alalalv\202\157\239w\198\026\227\218\206}\223alalalalalal\157\239\228\250\000\128al\000\128\000\128al\000\128alalalalalalr\169\244\177\208\148\244\177v\202alW\190r\169\244\177\150\161alalal\218\206}\223\248\218}\223\248\218W\190alalalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalalW\190\150\161\248\218}\223\222\223\157\239alal\157\239}\223alalalal\218\206\218\206\218\206\218\206}\223W\190alalalalalal}\223c\251\000\128al\000\128\000\128al\000\128alalalalalv\2023\157alal\218\206alalalalalalalalal\248\218v\202\157\239\218\206\157\239v\202alalalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalal\157\239}\223\150\161\218\206alv\202\157\239\150\161W\190\248\218al}\223alal}\223\248\218\218\206}\223\248\218}\223\248\218\222\223alalalalal\157\239l\251\000\128al\000\128\000\128al\000\128alalalalv\202\218\206r\169}\223\157\239v\202\157\239al\244\177\150\161\157\239W\190alalv\202}\223}\223v\202}\223\218\206\248\218}\223alalalalal\157\239c\251\000\128al\000\128\000\128al\000\128alalalalal\218\206\248\218\244\177v\202\244\1773\157\208\148W\190\218\206\218\206\218\206al\157\239v\202\218\206\218\206}\223r\169\218\206v\202\244\177\218\206}\223alalal5\227l\251\000\128al\000\128\000\128al\000\128alalalalalalal\157\239alal\157\239\218\206alalalal}\223v\202W\190\218\206\248\218v\202\157\239}\223alalal\248\218\157\239alal\157\239l\251\000\128al\000\128\000\128al\000\128alalal\165\232alalal}\223alalalalalalal\218\206\218\206r\169\150\161W\190\248\218W\190\222\223\150\161v\202W\190W\190W\190\157\239alal}\223l\251\000\128al\000\128\000\128al\000\128alalQ\246\165\232Q\246alal\218\206}\223\157\239\218\206\150\161\157\239}\223\248\218W\190\218\206\157\239\157\239\244\177\150\161\208\148C\188C\188\133\136C\148\177\1363\157alalal5\227l\251\000\128al\000\128\000\128al\000\128al\148\250\165\232\165\232\165\232\148\250al\248\218\248\218W\190\133\136C\208\206\176\150\161\150\161\150\161\150\161W\190\177\136D\168\001\248\001\248C\188\133\136C\148\001\248\001\248\001\248\206\176}\223al\157\239l\251\000\128al\000\128\000\128al\000\128\205\241\165\232\165\232\165\232\165\232\165\232\205\241\177\1363\157\244\177C\132C\132C\148C\208\165\236C\208\001\248\001\248\001\248\001\248C\188\133\136C\132\177\136\001\248\165\200C\208\133\136\001\248C\208\218\206\218\206\243\251\000\128al\000\128\000\128al\000\128\205\241\165\232\165\232\165\232\165\232\165\232R\246C\148j\161alP\128P\128\198\148C\132C\148C\208\001\248\001\248C\188\133\136C\132\007\157J\173\165\236C\208C\208\133\136\133\136C\208\228\250\228\201C\132\243\251\000\128al\000\128\000\128al\000\128alr\238\165\232\165\232\165\232\148\250al\203\185C\132alD\173\229\251N\202P\128\133\136C\132C\148\133\136C\132J\173J\173d\222D\205\001\248C\208\001\248\133\136C\188D\205\228\250C\132\198\148\243\251\000\128al\000\128\000\128al\000\128\184\210alQ\246\165\232Q\246al\211\218C\132C\132v\202\204\226d\222\228\213\228\250l\251P\128\133\136\198\148P\128\196\234\196\234E\206\001\248C\208\001\248\198\248\001\248\001\248c\251\133\136\203\185C\132\243\251\000\128al\000\128\000\128al\000\128\210\218alal\165\2321\198al\140\173J\173\007\157\198\148alD\173\196\234f\250E\206\228\213l\251\196\234\228\213\228\213\228\250\197\216C\208\165\236\001\248\001\248\001\248D\205d\222J\173r\169\198\148\243\251\000\128al\000\128\000\128al\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128al\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232al\165\232\165\232\205\241alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232al\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alal\165\232\165\232\165\232\205\241alalalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\165\232\165\232\165\232\205\241alalalal\000\128\000\128alal\165\232\165\232\165\232\165\232\205\241alalalalalalalal\205\241\165\232\165\232\165\232\165\232\165\232\205\241alalalalalalal\165\232\165\232\165\232\165\232\205\241alalal\000\128\000\128alal\165\232\165\232al\165\232\165\232\205\241alalalalalalalal\148\250\165\232\165\232\165\232\148\250alalalalalalalal\165\232\165\232al\165\232\165\232\205\241alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalQ\246\165\232Q\246alalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128\000\128alal\165\232\165\232alal\165\232\165\232alalalalalalalalalal\165\232alalalalalalalalalal\165\232\165\232alal\165\232\165\232alal\000\128al\000\128alalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalalal\000\128alalal\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\128alal")

